/*
 * Copyright (C) 2010-2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <wtf/EnumTraits.h>

namespace IPC {

enum class ReceiverName : uint8_t {
    GPUConnectionToWebProcess = 1
    , GPUProcess = 2
    , RemoteRenderingBackendProxy = 3
    , RemoteAudioDestinationManager = 4
    , RemoteAudioSessionProxy = 5
    , RemoteCDMFactoryProxy = 6
    , RemoteCDMInstanceProxy = 7
    , RemoteCDMInstanceSessionProxy = 8
    , RemoteCDMProxy = 9
    , RemoteLegacyCDMFactoryProxy = 10
    , RemoteLegacyCDMProxy = 11
    , RemoteLegacyCDMSessionProxy = 12
    , RemoteMediaPlayerManagerProxy = 13
    , RemoteMediaPlayerProxy = 14
    , RemoteMediaResourceManager = 15
    , LibWebRTCCodecsProxy = 16
    , RemoteAudioMediaStreamTrackRenderer = 17
    , RemoteAudioMediaStreamTrackRendererManager = 18
    , RemoteMediaRecorder = 19
    , RemoteMediaRecorderManager = 20
    , RemoteSampleBufferDisplayLayer = 21
    , RemoteSampleBufferDisplayLayerManager = 22
    , WebCookieManager = 23
    , WebIDBServer = 24
    , NetworkConnectionToWebProcess = 25
    , NetworkContentRuleListManager = 26
    , NetworkProcess = 27
    , NetworkResourceLoader = 28
    , NetworkSocketChannel = 29
    , NetworkSocketStream = 30
    , ServiceWorkerFetchTask = 31
    , WebSWServerConnection = 32
    , WebSWServerToContextConnection = 33
    , StorageManagerSet = 34
    , CacheStorageEngineConnection = 35
    , NetworkMDNSRegister = 36
    , NetworkRTCMonitor = 37
    , NetworkRTCProvider = 38
    , NetworkRTCSocket = 39
    , PluginControllerProxy = 40
    , PluginProcess = 41
    , WebProcessConnection = 42
    , AuxiliaryProcess = 43
    , WebConnection = 44
    , AuthenticationManager = 45
    , NPObjectMessageReceiver = 46
    , DrawingAreaProxy = 47
    , VisitedLinkStore = 48
    , WebCookieManagerProxy = 49
    , WebFullScreenManagerProxy = 50
    , WebGeolocationManagerProxy = 51
    , WebPageProxy = 52
    , WebPasteboardProxy = 53
    , WebProcessPool = 54
    , WebProcessProxy = 55
    , WebAutomationSession = 56
    , DownloadProxy = 57
    , GPUProcessProxy = 58
    , RemoteWebInspectorProxy = 59
    , WebInspectorProxy = 60
    , NetworkProcessProxy = 61
    , PluginProcessProxy = 62
    , WebUserContentControllerProxy = 63
    , WebProcess = 64
    , WebAutomationSessionProxy = 65
    , WebIDBConnectionToServer = 66
    , WebFullScreenManager = 67
    , GPUProcessConnection = 68
    , RemoteRenderingBackend = 69
    , MediaPlayerPrivateRemote = 70
    , RemoteAudioDestinationProxy = 71
    , RemoteAudioSession = 72
    , RemoteCDMInstanceSession = 73
    , RemoteLegacyCDMSession = 74
    , RemoteMediaPlayerManager = 75
    , LibWebRTCCodecs = 76
    , SampleBufferDisplayLayer = 77
    , WebGeolocationManager = 78
    , RemoteWebInspectorUI = 79
    , WebInspector = 80
    , WebInspectorInterruptDispatcher = 81
    , WebInspectorUI = 82
    , LibWebRTCNetwork = 83
    , WebMDNSRegister = 84
    , WebRTCMonitor = 85
    , WebRTCResolver = 86
    , NetworkProcessConnection = 87
    , WebResourceLoader = 88
    , WebSocketChannel = 89
    , WebSocketStream = 90
    , WebNotificationManager = 91
    , PluginProcessConnection = 92
    , PluginProcessConnectionManager = 93
    , PluginProxy = 94
    , WebSWClientConnection = 95
    , WebSWContextManagerConnection = 96
    , WebUserContentController = 97
    , DrawingArea = 98
    , EventDispatcher = 99
    , VisitedLinkTableController = 100
    , WebPage = 101
    , StorageAreaMap = 102
    , ViewGestureController = 103
    , ViewGestureGeometryCollector = 104
    , IPC = 105
    , AsyncReply = 106
    , Invalid = 107
};

enum class MessageName : uint16_t {
    GPUConnectionToWebProcess_CreateRenderingBackend = 1
    , GPUConnectionToWebProcess_ReleaseRenderingBackend = 2
    , GPUConnectionToWebProcess_ClearNowPlayingInfo = 3
    , GPUConnectionToWebProcess_SetNowPlayingInfo = 4
#if USE(AUDIO_SESSION)
    , GPUConnectionToWebProcess_EnsureAudioSession = 5
#endif
#if PLATFORM(IOS_FAMILY)
    , GPUConnectionToWebProcess_EnsureMediaSessionHelper = 6
#endif
    , GPUProcess_InitializeGPUProcess = 7
    , GPUProcess_CreateGPUConnectionToWebProcess = 8
    , GPUProcess_CreateGPUConnectionToWebProcessReply = 9
    , GPUProcess_ProcessDidTransitionToForeground = 10
    , GPUProcess_ProcessDidTransitionToBackground = 11
    , GPUProcess_AddSession = 12
    , GPUProcess_RemoveSession = 13
#if ENABLE(MEDIA_STREAM)
    , GPUProcess_SetMockCaptureDevicesEnabled = 14
#endif
#if ENABLE(MEDIA_STREAM)
    , GPUProcess_SetOrientationForMediaCapture = 15
#endif
#if ENABLE(MEDIA_STREAM)
    , GPUProcess_UpdateCaptureAccess = 16
    , GPUProcess_UpdateCaptureAccessReply = 17
#endif
    , RemoteRenderingBackendProxy_CreateImageBuffer = 18
    , RemoteRenderingBackendProxy_ReleaseImageBuffer = 19
    , RemoteRenderingBackendProxy_FlushImageBufferDrawingContext = 20
    , RemoteRenderingBackendProxy_FlushImageBufferDrawingContextAndCommit = 21
    , RemoteRenderingBackendProxy_GetImageData = 22
    , RemoteAudioDestinationManager_CreateAudioDestination = 23
    , RemoteAudioDestinationManager_DeleteAudioDestination = 24
    , RemoteAudioDestinationManager_DeleteAudioDestinationReply = 25
    , RemoteAudioDestinationManager_StartAudioDestination = 26
    , RemoteAudioDestinationManager_StopAudioDestination = 27
    , RemoteAudioSessionProxy_SetCategory = 28
    , RemoteAudioSessionProxy_SetPreferredBufferSize = 29
    , RemoteAudioSessionProxy_TryToSetActive = 30
    , RemoteCDMFactoryProxy_CreateCDM = 31
    , RemoteCDMFactoryProxy_SupportsKeySystem = 32
    , RemoteCDMInstanceProxy_CreateSession = 33
    , RemoteCDMInstanceProxy_InitializeWithConfiguration = 34
    , RemoteCDMInstanceProxy_InitializeWithConfigurationReply = 35
    , RemoteCDMInstanceProxy_SetServerCertificate = 36
    , RemoteCDMInstanceProxy_SetServerCertificateReply = 37
    , RemoteCDMInstanceProxy_SetStorageDirectory = 38
    , RemoteCDMInstanceSessionProxy_RequestLicense = 39
    , RemoteCDMInstanceSessionProxy_RequestLicenseReply = 40
    , RemoteCDMInstanceSessionProxy_UpdateLicense = 41
    , RemoteCDMInstanceSessionProxy_UpdateLicenseReply = 42
    , RemoteCDMInstanceSessionProxy_LoadSession = 43
    , RemoteCDMInstanceSessionProxy_LoadSessionReply = 44
    , RemoteCDMInstanceSessionProxy_CloseSession = 45
    , RemoteCDMInstanceSessionProxy_CloseSessionReply = 46
    , RemoteCDMInstanceSessionProxy_RemoveSessionData = 47
    , RemoteCDMInstanceSessionProxy_RemoveSessionDataReply = 48
    , RemoteCDMInstanceSessionProxy_StoreRecordOfKeyUsage = 49
    , RemoteCDMProxy_GetSupportedConfiguration = 50
    , RemoteCDMProxy_GetSupportedConfigurationReply = 51
    , RemoteCDMProxy_CreateInstance = 52
    , RemoteCDMProxy_LoadAndInitialize = 53
    , RemoteLegacyCDMFactoryProxy_CreateCDM = 54
    , RemoteLegacyCDMFactoryProxy_SupportsKeySystem = 55
    , RemoteLegacyCDMProxy_SupportsMIMEType = 56
    , RemoteLegacyCDMProxy_CreateSession = 57
    , RemoteLegacyCDMProxy_SetPlayerId = 58
    , RemoteLegacyCDMSessionProxy_GenerateKeyRequest = 59
    , RemoteLegacyCDMSessionProxy_ReleaseKeys = 60
    , RemoteLegacyCDMSessionProxy_Update = 61
    , RemoteLegacyCDMSessionProxy_CachedKeyForKeyID = 62
    , RemoteMediaPlayerManagerProxy_CreateMediaPlayer = 63
    , RemoteMediaPlayerManagerProxy_CreateMediaPlayerReply = 64
    , RemoteMediaPlayerManagerProxy_DeleteMediaPlayer = 65
    , RemoteMediaPlayerManagerProxy_GetSupportedTypes = 66
    , RemoteMediaPlayerManagerProxy_SupportsTypeAndCodecs = 67
    , RemoteMediaPlayerManagerProxy_CanDecodeExtendedType = 68
    , RemoteMediaPlayerManagerProxy_OriginsInMediaCache = 69
    , RemoteMediaPlayerManagerProxy_ClearMediaCache = 70
    , RemoteMediaPlayerManagerProxy_ClearMediaCacheForOrigins = 71
    , RemoteMediaPlayerManagerProxy_SupportsKeySystem = 72
    , RemoteMediaPlayerProxy_PrepareForPlayback = 73
    , RemoteMediaPlayerProxy_PrepareForPlaybackReply = 74
    , RemoteMediaPlayerProxy_Load = 75
    , RemoteMediaPlayerProxy_LoadReply = 76
    , RemoteMediaPlayerProxy_CancelLoad = 77
    , RemoteMediaPlayerProxy_PrepareToPlay = 78
    , RemoteMediaPlayerProxy_Play = 79
    , RemoteMediaPlayerProxy_Pause = 80
    , RemoteMediaPlayerProxy_SetVolume = 81
    , RemoteMediaPlayerProxy_SetMuted = 82
    , RemoteMediaPlayerProxy_Seek = 83
    , RemoteMediaPlayerProxy_SeekWithTolerance = 84
    , RemoteMediaPlayerProxy_SetPreload = 85
    , RemoteMediaPlayerProxy_SetPrivateBrowsingMode = 86
    , RemoteMediaPlayerProxy_SetPreservesPitch = 87
    , RemoteMediaPlayerProxy_PrepareForRendering = 88
    , RemoteMediaPlayerProxy_SetVisible = 89
    , RemoteMediaPlayerProxy_SetShouldMaintainAspectRatio = 90
#if ENABLE(VIDEO_PRESENTATION_MODE)
    , RemoteMediaPlayerProxy_SetVideoFullscreenGravity = 91
#endif
    , RemoteMediaPlayerProxy_AcceleratedRenderingStateChanged = 92
    , RemoteMediaPlayerProxy_SetShouldDisableSleep = 93
    , RemoteMediaPlayerProxy_SetRate = 94
#if ENABLE(VIDEO_PRESENTATION_MODE)
    , RemoteMediaPlayerProxy_UpdateVideoFullscreenInlineImage = 95
#endif
#if ENABLE(VIDEO_PRESENTATION_MODE)
    , RemoteMediaPlayerProxy_SetVideoFullscreenMode = 96
#endif
#if ENABLE(VIDEO_PRESENTATION_MODE)
    , RemoteMediaPlayerProxy_VideoFullscreenStandbyChanged = 97
#endif
    , RemoteMediaPlayerProxy_SetBufferingPolicy = 98
    , RemoteMediaPlayerProxy_AudioTrackSetEnabled = 99
    , RemoteMediaPlayerProxy_VideoTrackSetSelected = 100
    , RemoteMediaPlayerProxy_TextTrackSetMode = 101
#if PLATFORM(COCOA)
    , RemoteMediaPlayerProxy_SetVideoInlineSizeFenced = 102
#endif
#if (PLATFORM(COCOA) && ENABLE(VIDEO_PRESENTATION_MODE))
    , RemoteMediaPlayerProxy_SetVideoFullscreenFrameFenced = 103
#endif
#if ENABLE(VIDEO_PRESENTATION_MODE)
    , RemoteMediaPlayerProxy_EnterFullscreen = 104
    , RemoteMediaPlayerProxy_EnterFullscreenReply = 105
#endif
#if ENABLE(VIDEO_PRESENTATION_MODE)
    , RemoteMediaPlayerProxy_ExitFullscreen = 106
    , RemoteMediaPlayerProxy_ExitFullscreenReply = 107
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET)
    , RemoteMediaPlayerProxy_SetWirelessVideoPlaybackDisabled = 108
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET)
    , RemoteMediaPlayerProxy_SetShouldPlayToPlaybackTarget = 109
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    , RemoteMediaPlayerProxy_SetLegacyCDMSession = 110
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    , RemoteMediaPlayerProxy_KeyAdded = 111
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    , RemoteMediaPlayerProxy_CdmInstanceAttached = 112
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    , RemoteMediaPlayerProxy_CdmInstanceDetached = 113
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    , RemoteMediaPlayerProxy_AttemptToDecryptWithInstance = 114
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA) && ENABLE(ENCRYPTED_MEDIA)
    , RemoteMediaPlayerProxy_SetShouldContinueAfterKeyNeeded = 115
#endif
    , RemoteMediaPlayerProxy_BeginSimulatedHDCPError = 116
    , RemoteMediaPlayerProxy_EndSimulatedHDCPError = 117
    , RemoteMediaPlayerProxy_NotifyActiveSourceBuffersChanged = 118
    , RemoteMediaPlayerProxy_ApplicationWillResignActive = 119
    , RemoteMediaPlayerProxy_ApplicationDidBecomeActive = 120
    , RemoteMediaPlayerProxy_NotifyTrackModeChanged = 121
    , RemoteMediaPlayerProxy_TracksChanged = 122
    , RemoteMediaPlayerProxy_SyncTextTrackBounds = 123
#if ENABLE(WIRELESS_PLAYBACK_TARGET)
    , RemoteMediaPlayerProxy_SetWirelessPlaybackTarget = 124
#endif
    , RemoteMediaPlayerProxy_PerformTaskAtMediaTime = 125
    , RemoteMediaPlayerProxy_PerformTaskAtMediaTimeReply = 126
    , RemoteMediaPlayerProxy_WouldTaintOrigin = 127
#if PLATFORM(IOS_FAMILY)
    , RemoteMediaPlayerProxy_ErrorLog = 128
#endif
#if PLATFORM(IOS_FAMILY)
    , RemoteMediaPlayerProxy_AccessLog = 129
#endif
    , RemoteMediaResourceManager_ResponseReceived = 130
    , RemoteMediaResourceManager_ResponseReceivedReply = 131
    , RemoteMediaResourceManager_RedirectReceived = 132
    , RemoteMediaResourceManager_RedirectReceivedReply = 133
    , RemoteMediaResourceManager_DataSent = 134
    , RemoteMediaResourceManager_DataReceived = 135
    , RemoteMediaResourceManager_AccessControlCheckFailed = 136
    , RemoteMediaResourceManager_LoadFailed = 137
    , RemoteMediaResourceManager_LoadFinished = 138
    , LibWebRTCCodecsProxy_CreateH264Decoder = 139
    , LibWebRTCCodecsProxy_CreateH265Decoder = 140
    , LibWebRTCCodecsProxy_ReleaseDecoder = 141
    , LibWebRTCCodecsProxy_DecodeFrame = 142
    , LibWebRTCCodecsProxy_CreateEncoder = 143
    , LibWebRTCCodecsProxy_ReleaseEncoder = 144
    , LibWebRTCCodecsProxy_InitializeEncoder = 145
    , LibWebRTCCodecsProxy_EncodeFrame = 146
    , LibWebRTCCodecsProxy_SetEncodeRates = 147
    , RemoteAudioMediaStreamTrackRenderer_Start = 148
    , RemoteAudioMediaStreamTrackRenderer_Stop = 149
    , RemoteAudioMediaStreamTrackRenderer_Clear = 150
    , RemoteAudioMediaStreamTrackRenderer_SetVolume = 151
    , RemoteAudioMediaStreamTrackRenderer_AudioSamplesStorageChanged = 152
    , RemoteAudioMediaStreamTrackRenderer_AudioSamplesAvailable = 153
    , RemoteAudioMediaStreamTrackRendererManager_CreateRenderer = 154
    , RemoteAudioMediaStreamTrackRendererManager_ReleaseRenderer = 155
    , RemoteMediaRecorder_AudioSamplesStorageChanged = 156
    , RemoteMediaRecorder_AudioSamplesAvailable = 157
    , RemoteMediaRecorder_VideoSampleAvailable = 158
    , RemoteMediaRecorder_FetchData = 159
    , RemoteMediaRecorder_FetchDataReply = 160
    , RemoteMediaRecorder_StopRecording = 161
    , RemoteMediaRecorderManager_CreateRecorder = 162
    , RemoteMediaRecorderManager_CreateRecorderReply = 163
    , RemoteMediaRecorderManager_ReleaseRecorder = 164
    , RemoteSampleBufferDisplayLayer_UpdateDisplayMode = 165
    , RemoteSampleBufferDisplayLayer_UpdateAffineTransform = 166
    , RemoteSampleBufferDisplayLayer_UpdateBoundsAndPosition = 167
    , RemoteSampleBufferDisplayLayer_Flush = 168
    , RemoteSampleBufferDisplayLayer_FlushAndRemoveImage = 169
    , RemoteSampleBufferDisplayLayer_EnqueueSample = 170
    , RemoteSampleBufferDisplayLayer_ClearEnqueuedSamples = 171
    , RemoteSampleBufferDisplayLayerManager_CreateLayer = 172
    , RemoteSampleBufferDisplayLayerManager_CreateLayerReply = 173
    , RemoteSampleBufferDisplayLayerManager_ReleaseLayer = 174
    , WebCookieManager_GetHostnamesWithCookies = 175
    , WebCookieManager_GetHostnamesWithCookiesReply = 176
    , WebCookieManager_DeleteCookiesForHostnames = 177
    , WebCookieManager_DeleteAllCookies = 178
    , WebCookieManager_SetCookie = 179
    , WebCookieManager_SetCookieReply = 180
    , WebCookieManager_SetCookies = 181
    , WebCookieManager_SetCookiesReply = 182
    , WebCookieManager_GetAllCookies = 183
    , WebCookieManager_GetAllCookiesReply = 184
    , WebCookieManager_GetCookies = 185
    , WebCookieManager_GetCookiesReply = 186
    , WebCookieManager_DeleteCookie = 187
    , WebCookieManager_DeleteCookieReply = 188
    , WebCookieManager_DeleteAllCookiesModifiedSince = 189
    , WebCookieManager_DeleteAllCookiesModifiedSinceReply = 190
    , WebCookieManager_SetHTTPCookieAcceptPolicy = 191
    , WebCookieManager_SetHTTPCookieAcceptPolicyReply = 192
    , WebCookieManager_GetHTTPCookieAcceptPolicy = 193
    , WebCookieManager_GetHTTPCookieAcceptPolicyReply = 194
    , WebCookieManager_StartObservingCookieChanges = 195
    , WebCookieManager_StopObservingCookieChanges = 196
#if USE(SOUP)
    , WebCookieManager_SetCookiePersistentStorage = 197
#endif
    , WebIDBServer_DeleteDatabase = 198
    , WebIDBServer_OpenDatabase = 199
    , WebIDBServer_AbortTransaction = 200
    , WebIDBServer_CommitTransaction = 201
    , WebIDBServer_DidFinishHandlingVersionChangeTransaction = 202
    , WebIDBServer_CreateObjectStore = 203
    , WebIDBServer_DeleteObjectStore = 204
    , WebIDBServer_RenameObjectStore = 205
    , WebIDBServer_ClearObjectStore = 206
    , WebIDBServer_CreateIndex = 207
    , WebIDBServer_DeleteIndex = 208
    , WebIDBServer_RenameIndex = 209
    , WebIDBServer_PutOrAdd = 210
    , WebIDBServer_GetRecord = 211
    , WebIDBServer_GetAllRecords = 212
    , WebIDBServer_GetCount = 213
    , WebIDBServer_DeleteRecord = 214
    , WebIDBServer_OpenCursor = 215
    , WebIDBServer_IterateCursor = 216
    , WebIDBServer_EstablishTransaction = 217
    , WebIDBServer_DatabaseConnectionPendingClose = 218
    , WebIDBServer_DatabaseConnectionClosed = 219
    , WebIDBServer_AbortOpenAndUpgradeNeeded = 220
    , WebIDBServer_DidFireVersionChangeEvent = 221
    , WebIDBServer_OpenDBRequestCancelled = 222
    , WebIDBServer_GetAllDatabaseNamesAndVersions = 223
    , NetworkConnectionToWebProcess_ScheduleResourceLoad = 224
    , NetworkConnectionToWebProcess_PerformSynchronousLoad = 225
    , NetworkConnectionToWebProcess_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply = 226
    , NetworkConnectionToWebProcess_LoadPing = 227
    , NetworkConnectionToWebProcess_RemoveLoadIdentifier = 228
    , NetworkConnectionToWebProcess_PageLoadCompleted = 229
    , NetworkConnectionToWebProcess_BrowsingContextRemoved = 230
    , NetworkConnectionToWebProcess_PrefetchDNS = 231
    , NetworkConnectionToWebProcess_PreconnectTo = 232
    , NetworkConnectionToWebProcess_StartDownload = 233
    , NetworkConnectionToWebProcess_ConvertMainResourceLoadToDownload = 234
    , NetworkConnectionToWebProcess_CookiesForDOM = 235
    , NetworkConnectionToWebProcess_SetCookiesFromDOM = 236
    , NetworkConnectionToWebProcess_CookieRequestHeaderFieldValue = 237
    , NetworkConnectionToWebProcess_GetRawCookies = 238
    , NetworkConnectionToWebProcess_SetRawCookie = 239
    , NetworkConnectionToWebProcess_DeleteCookie = 240
    , NetworkConnectionToWebProcess_DomCookiesForHost = 241
#if HAVE(COOKIE_CHANGE_LISTENER_API)
    , NetworkConnectionToWebProcess_UnsubscribeFromCookieChangeNotifications = 242
#endif
    , NetworkConnectionToWebProcess_RegisterFileBlobURL = 243
    , NetworkConnectionToWebProcess_RegisterBlobURL = 244
    , NetworkConnectionToWebProcess_RegisterBlobURLFromURL = 245
    , NetworkConnectionToWebProcess_RegisterBlobURLOptionallyFileBacked = 246
    , NetworkConnectionToWebProcess_RegisterBlobURLForSlice = 247
    , NetworkConnectionToWebProcess_UnregisterBlobURL = 248
    , NetworkConnectionToWebProcess_BlobSize = 249
    , NetworkConnectionToWebProcess_WriteBlobsToTemporaryFiles = 250
    , NetworkConnectionToWebProcess_WriteBlobsToTemporaryFilesReply = 251
    , NetworkConnectionToWebProcess_SetCaptureExtraNetworkLoadMetricsEnabled = 252
    , NetworkConnectionToWebProcess_CreateSocketStream = 253
    , NetworkConnectionToWebProcess_CreateSocketChannel = 254
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkConnectionToWebProcess_RemoveStorageAccessForFrame = 255
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkConnectionToWebProcess_ClearPageSpecificDataForResourceLoadStatistics = 256
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkConnectionToWebProcess_LogUserInteraction = 257
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkConnectionToWebProcess_ResourceLoadStatisticsUpdated = 258
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkConnectionToWebProcess_HasStorageAccess = 259
    , NetworkConnectionToWebProcess_HasStorageAccessReply = 260
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkConnectionToWebProcess_RequestStorageAccess = 261
    , NetworkConnectionToWebProcess_RequestStorageAccessReply = 262
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkConnectionToWebProcess_RequestStorageAccessUnderOpener = 263
#endif
    , NetworkConnectionToWebProcess_AddOriginAccessWhitelistEntry = 264
    , NetworkConnectionToWebProcess_RemoveOriginAccessWhitelistEntry = 265
    , NetworkConnectionToWebProcess_ResetOriginAccessWhitelists = 266
    , NetworkConnectionToWebProcess_GetNetworkLoadInformationResponse = 267
    , NetworkConnectionToWebProcess_GetNetworkLoadIntermediateInformation = 268
    , NetworkConnectionToWebProcess_TakeNetworkLoadInformationMetrics = 269
#if ENABLE(SERVICE_WORKER)
    , NetworkConnectionToWebProcess_EstablishSWContextConnection = 270
    , NetworkConnectionToWebProcess_EstablishSWContextConnectionReply = 271
#endif
#if ENABLE(SERVICE_WORKER)
    , NetworkConnectionToWebProcess_CloseSWContextConnection = 272
#endif
    , NetworkConnectionToWebProcess_UpdateQuotaBasedOnSpaceUsageForTesting = 273
    , NetworkConnectionToWebProcess_CreateNewMessagePortChannel = 274
    , NetworkConnectionToWebProcess_EntangleLocalPortInThisProcessToRemote = 275
    , NetworkConnectionToWebProcess_MessagePortDisentangled = 276
    , NetworkConnectionToWebProcess_MessagePortClosed = 277
    , NetworkConnectionToWebProcess_TakeAllMessagesForPort = 278
    , NetworkConnectionToWebProcess_TakeAllMessagesForPortReply = 279
    , NetworkConnectionToWebProcess_PostMessageToRemote = 280
    , NetworkConnectionToWebProcess_CheckRemotePortForActivity = 281
    , NetworkConnectionToWebProcess_CheckRemotePortForActivityReply = 282
    , NetworkConnectionToWebProcess_DidDeliverMessagePortMessages = 283
    , NetworkConnectionToWebProcess_RegisterURLSchemesAsCORSEnabled = 284
    , NetworkContentRuleListManager_Remove = 285
    , NetworkContentRuleListManager_AddContentRuleLists = 286
    , NetworkContentRuleListManager_RemoveContentRuleList = 287
    , NetworkContentRuleListManager_RemoveAllContentRuleLists = 288
    , NetworkProcess_InitializeNetworkProcess = 289
    , NetworkProcess_CreateNetworkConnectionToWebProcess = 290
    , NetworkProcess_CreateNetworkConnectionToWebProcessReply = 291
#if USE(SOUP)
    , NetworkProcess_SetIgnoreTLSErrors = 292
#endif
#if USE(SOUP)
    , NetworkProcess_UserPreferredLanguagesChanged = 293
#endif
#if USE(SOUP)
    , NetworkProcess_SetNetworkProxySettings = 294
#endif
#if USE(SOUP)
    , NetworkProcess_PrefetchDNS = 295
#endif
#if USE(SOUP)
    , NetworkProcess_SetPersistentCredentialStorageEnabled = 296
#endif
#if USE(CURL)
    , NetworkProcess_SetNetworkProxySettings = 297
#endif
    , NetworkProcess_ClearCachedCredentials = 298
    , NetworkProcess_AddWebsiteDataStore = 299
    , NetworkProcess_DestroySession = 300
    , NetworkProcess_FetchWebsiteData = 301
    , NetworkProcess_DeleteWebsiteData = 302
    , NetworkProcess_DeleteWebsiteDataForOrigins = 303
    , NetworkProcess_RenameOriginInWebsiteData = 304
    , NetworkProcess_RenameOriginInWebsiteDataReply = 305
    , NetworkProcess_DownloadRequest = 306
    , NetworkProcess_ResumeDownload = 307
    , NetworkProcess_CancelDownload = 308
#if PLATFORM(COCOA)
    , NetworkProcess_PublishDownloadProgress = 309
#endif
    , NetworkProcess_ApplicationDidEnterBackground = 310
    , NetworkProcess_ApplicationWillEnterForeground = 311
    , NetworkProcess_ContinueWillSendRequest = 312
    , NetworkProcess_ContinueDecidePendingDownloadDestination = 313
#if PLATFORM(COCOA)
    , NetworkProcess_SetQOS = 314
#endif
#if PLATFORM(COCOA)
    , NetworkProcess_SetStorageAccessAPIEnabled = 315
#endif
    , NetworkProcess_SetAllowsAnySSLCertificateForWebSocket = 316
    , NetworkProcess_SyncAllCookies = 317
    , NetworkProcess_AllowSpecificHTTPSCertificateForHost = 318
    , NetworkProcess_SetCacheModel = 319
    , NetworkProcess_SetCacheModelSynchronouslyForTesting = 320
    , NetworkProcess_ProcessDidTransitionToBackground = 321
    , NetworkProcess_ProcessDidTransitionToForeground = 322
    , NetworkProcess_ProcessWillSuspendImminentlyForTestingSync = 323
    , NetworkProcess_PrepareToSuspend = 324
    , NetworkProcess_PrepareToSuspendReply = 325
    , NetworkProcess_ProcessDidResume = 326
    , NetworkProcess_PreconnectTo = 327
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ClearPrevalentResource = 328
    , NetworkProcess_ClearPrevalentResourceReply = 329
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ClearUserInteraction = 330
    , NetworkProcess_ClearUserInteractionReply = 331
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_DumpResourceLoadStatistics = 332
    , NetworkProcess_DumpResourceLoadStatisticsReply = 333
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetResourceLoadStatisticsEnabled = 334
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetResourceLoadStatisticsLogTestingEvent = 335
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_UpdatePrevalentDomainsToBlockCookiesFor = 336
    , NetworkProcess_UpdatePrevalentDomainsToBlockCookiesForReply = 337
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsGrandfathered = 338
    , NetworkProcess_IsGrandfatheredReply = 339
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsPrevalentResource = 340
    , NetworkProcess_IsPrevalentResourceReply = 341
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsVeryPrevalentResource = 342
    , NetworkProcess_IsVeryPrevalentResourceReply = 343
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetAgeCapForClientSideCookies = 344
    , NetworkProcess_SetAgeCapForClientSideCookiesReply = 345
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetLastSeen = 346
    , NetworkProcess_SetLastSeenReply = 347
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_MergeStatisticForTesting = 348
    , NetworkProcess_MergeStatisticForTestingReply = 349
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_InsertExpiredStatisticForTesting = 350
    , NetworkProcess_InsertExpiredStatisticForTestingReply = 351
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetPrevalentResource = 352
    , NetworkProcess_SetPrevalentResourceReply = 353
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetPrevalentResourceForDebugMode = 354
    , NetworkProcess_SetPrevalentResourceForDebugModeReply = 355
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsResourceLoadStatisticsEphemeral = 356
    , NetworkProcess_IsResourceLoadStatisticsEphemeralReply = 357
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_HadUserInteraction = 358
    , NetworkProcess_HadUserInteractionReply = 359
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsRelationshipOnlyInDatabaseOnce = 360
    , NetworkProcess_IsRelationshipOnlyInDatabaseOnceReply = 361
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_HasLocalStorage = 362
    , NetworkProcess_HasLocalStorageReply = 363
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_GetAllStorageAccessEntries = 364
    , NetworkProcess_GetAllStorageAccessEntriesReply = 365
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsRegisteredAsRedirectingTo = 366
    , NetworkProcess_IsRegisteredAsRedirectingToReply = 367
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsRegisteredAsSubFrameUnder = 368
    , NetworkProcess_IsRegisteredAsSubFrameUnderReply = 369
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_IsRegisteredAsSubresourceUnder = 370
    , NetworkProcess_IsRegisteredAsSubresourceUnderReply = 371
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_DomainIDExistsInDatabase = 372
    , NetworkProcess_DomainIDExistsInDatabaseReply = 373
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_LogFrameNavigation = 374
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_LogUserInteraction = 375
    , NetworkProcess_LogUserInteractionReply = 376
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ResetParametersToDefaultValues = 377
    , NetworkProcess_ResetParametersToDefaultValuesReply = 378
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ScheduleClearInMemoryAndPersistent = 379
    , NetworkProcess_ScheduleClearInMemoryAndPersistentReply = 380
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ScheduleCookieBlockingUpdate = 381
    , NetworkProcess_ScheduleCookieBlockingUpdateReply = 382
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ScheduleStatisticsAndDataRecordsProcessing = 383
    , NetworkProcess_ScheduleStatisticsAndDataRecordsProcessingReply = 384
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_StatisticsDatabaseHasAllTables = 385
    , NetworkProcess_StatisticsDatabaseHasAllTablesReply = 386
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SubmitTelemetry = 387
    , NetworkProcess_SubmitTelemetryReply = 388
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetCacheMaxAgeCapForPrevalentResources = 389
    , NetworkProcess_SetCacheMaxAgeCapForPrevalentResourcesReply = 390
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetGrandfathered = 391
    , NetworkProcess_SetGrandfatheredReply = 392
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetUseITPDatabase = 393
    , NetworkProcess_SetUseITPDatabaseReply = 394
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_GetResourceLoadStatisticsDataSummary = 395
    , NetworkProcess_GetResourceLoadStatisticsDataSummaryReply = 396
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetGrandfatheringTime = 397
    , NetworkProcess_SetGrandfatheringTimeReply = 398
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetMaxStatisticsEntries = 399
    , NetworkProcess_SetMaxStatisticsEntriesReply = 400
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetMinimumTimeBetweenDataRecordsRemoval = 401
    , NetworkProcess_SetMinimumTimeBetweenDataRecordsRemovalReply = 402
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetPruneEntriesDownTo = 403
    , NetworkProcess_SetPruneEntriesDownToReply = 404
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetShouldClassifyResourcesBeforeDataRecordsRemoval = 405
    , NetworkProcess_SetShouldClassifyResourcesBeforeDataRecordsRemovalReply = 406
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetNotifyPagesWhenDataRecordsWereScanned = 407
    , NetworkProcess_SetNotifyPagesWhenDataRecordsWereScannedReply = 408
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetIsRunningResourceLoadStatisticsTest = 409
    , NetworkProcess_SetIsRunningResourceLoadStatisticsTestReply = 410
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetNotifyPagesWhenTelemetryWasCaptured = 411
    , NetworkProcess_SetNotifyPagesWhenTelemetryWasCapturedReply = 412
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetResourceLoadStatisticsDebugMode = 413
    , NetworkProcess_SetResourceLoadStatisticsDebugModeReply = 414
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetVeryPrevalentResource = 415
    , NetworkProcess_SetVeryPrevalentResourceReply = 416
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetSubframeUnderTopFrameDomain = 417
    , NetworkProcess_SetSubframeUnderTopFrameDomainReply = 418
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetSubresourceUnderTopFrameDomain = 419
    , NetworkProcess_SetSubresourceUnderTopFrameDomainReply = 420
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetSubresourceUniqueRedirectTo = 421
    , NetworkProcess_SetSubresourceUniqueRedirectToReply = 422
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetSubresourceUniqueRedirectFrom = 423
    , NetworkProcess_SetSubresourceUniqueRedirectFromReply = 424
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetTimeToLiveUserInteraction = 425
    , NetworkProcess_SetTimeToLiveUserInteractionReply = 426
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetTopFrameUniqueRedirectTo = 427
    , NetworkProcess_SetTopFrameUniqueRedirectToReply = 428
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetTopFrameUniqueRedirectFrom = 429
    , NetworkProcess_SetTopFrameUniqueRedirectFromReply = 430
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ResetCacheMaxAgeCapForPrevalentResources = 431
    , NetworkProcess_ResetCacheMaxAgeCapForPrevalentResourcesReply = 432
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_DidCommitCrossSiteLoadWithDataTransfer = 433
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetCrossSiteLoadWithLinkDecorationForTesting = 434
    , NetworkProcess_SetCrossSiteLoadWithLinkDecorationForTestingReply = 435
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_ResetCrossSiteLoadsWithLinkDecorationForTesting = 436
    , NetworkProcess_ResetCrossSiteLoadsWithLinkDecorationForTestingReply = 437
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_DeleteCookiesForTesting = 438
    , NetworkProcess_DeleteCookiesForTestingReply = 439
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_HasIsolatedSession = 440
    , NetworkProcess_HasIsolatedSessionReply = 441
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetAppBoundDomainsForResourceLoadStatistics = 442
    , NetworkProcess_SetAppBoundDomainsForResourceLoadStatisticsReply = 443
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetShouldDowngradeReferrerForTesting = 444
    , NetworkProcess_SetShouldDowngradeReferrerForTestingReply = 445
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetThirdPartyCookieBlockingMode = 446
    , NetworkProcess_SetThirdPartyCookieBlockingModeReply = 447
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetShouldEnbleSameSiteStrictEnforcementForTesting = 448
    , NetworkProcess_SetShouldEnbleSameSiteStrictEnforcementForTestingReply = 449
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetFirstPartyWebsiteDataRemovalModeForTesting = 450
    , NetworkProcess_SetFirstPartyWebsiteDataRemovalModeForTestingReply = 451
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcess_SetToSameSiteStrictCookiesForTesting = 452
    , NetworkProcess_SetToSameSiteStrictCookiesForTestingReply = 453
#endif
    , NetworkProcess_SetAdClickAttributionDebugMode = 454
    , NetworkProcess_SetSessionIsControlledByAutomation = 455
    , NetworkProcess_RegisterURLSchemeAsSecure = 456
    , NetworkProcess_RegisterURLSchemeAsBypassingContentSecurityPolicy = 457
    , NetworkProcess_RegisterURLSchemeAsLocal = 458
    , NetworkProcess_RegisterURLSchemeAsNoAccess = 459
    , NetworkProcess_SetCacheStorageParameters = 460
    , NetworkProcess_SyncLocalStorage = 461
    , NetworkProcess_ClearLegacyPrivateBrowsingLocalStorage = 462
    , NetworkProcess_StoreAdClickAttribution = 463
    , NetworkProcess_DumpAdClickAttribution = 464
    , NetworkProcess_DumpAdClickAttributionReply = 465
    , NetworkProcess_ClearAdClickAttribution = 466
    , NetworkProcess_ClearAdClickAttributionReply = 467
    , NetworkProcess_SetAdClickAttributionOverrideTimerForTesting = 468
    , NetworkProcess_SetAdClickAttributionOverrideTimerForTestingReply = 469
    , NetworkProcess_SetAdClickAttributionConversionURLForTesting = 470
    , NetworkProcess_SetAdClickAttributionConversionURLForTestingReply = 471
    , NetworkProcess_MarkAdClickAttributionsAsExpiredForTesting = 472
    , NetworkProcess_MarkAdClickAttributionsAsExpiredForTestingReply = 473
    , NetworkProcess_GetLocalStorageOriginDetails = 474
    , NetworkProcess_GetLocalStorageOriginDetailsReply = 475
    , NetworkProcess_SetServiceWorkerFetchTimeoutForTesting = 476
    , NetworkProcess_ResetServiceWorkerFetchTimeoutForTesting = 477
    , NetworkProcess_ResetQuota = 478
    , NetworkProcess_ResetQuotaReply = 479
    , NetworkProcess_HasAppBoundSession = 480
    , NetworkProcess_HasAppBoundSessionReply = 481
    , NetworkProcess_ClearAppBoundSession = 482
    , NetworkProcess_ClearAppBoundSessionReply = 483
#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)
    , NetworkProcess_DisableServiceWorkerEntitlement = 484
#endif
#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)
    , NetworkProcess_ClearServiceWorkerEntitlementOverride = 485
    , NetworkProcess_ClearServiceWorkerEntitlementOverrideReply = 486
#endif
    , NetworkProcess_UpdateBundleIdentifier = 487
    , NetworkProcess_UpdateBundleIdentifierReply = 488
    , NetworkProcess_ClearBundleIdentifier = 489
    , NetworkProcess_ClearBundleIdentifierReply = 490
    , NetworkResourceLoader_ContinueWillSendRequest = 491
    , NetworkResourceLoader_ContinueDidReceiveResponse = 492
    , NetworkSocketChannel_SendString = 493
    , NetworkSocketChannel_SendStringReply = 494
    , NetworkSocketChannel_SendData = 495
    , NetworkSocketChannel_SendDataReply = 496
    , NetworkSocketChannel_Close = 497
    , NetworkSocketStream_SendData = 498
    , NetworkSocketStream_SendHandshake = 499
    , NetworkSocketStream_Close = 500
    , ServiceWorkerFetchTask_DidNotHandle = 501
    , ServiceWorkerFetchTask_DidFail = 502
    , ServiceWorkerFetchTask_DidReceiveRedirectResponse = 503
    , ServiceWorkerFetchTask_DidReceiveResponse = 504
    , ServiceWorkerFetchTask_DidReceiveData = 505
    , ServiceWorkerFetchTask_DidReceiveSharedBuffer = 506
    , ServiceWorkerFetchTask_DidReceiveFormData = 507
    , ServiceWorkerFetchTask_DidFinish = 508
    , WebSWServerConnection_ScheduleJobInServer = 509
    , WebSWServerConnection_ScheduleUnregisterJobInServer = 510
    , WebSWServerConnection_ScheduleUnregisterJobInServerReply = 511
    , WebSWServerConnection_FinishFetchingScriptInServer = 512
    , WebSWServerConnection_AddServiceWorkerRegistrationInServer = 513
    , WebSWServerConnection_RemoveServiceWorkerRegistrationInServer = 514
    , WebSWServerConnection_PostMessageToServiceWorker = 515
    , WebSWServerConnection_DidResolveRegistrationPromise = 516
    , WebSWServerConnection_MatchRegistration = 517
    , WebSWServerConnection_WhenRegistrationReady = 518
    , WebSWServerConnection_GetRegistrations = 519
    , WebSWServerConnection_RegisterServiceWorkerClient = 520
    , WebSWServerConnection_UnregisterServiceWorkerClient = 521
    , WebSWServerConnection_TerminateWorkerFromClient = 522
    , WebSWServerConnection_TerminateWorkerFromClientReply = 523
    , WebSWServerConnection_WhenServiceWorkerIsTerminatedForTesting = 524
    , WebSWServerConnection_WhenServiceWorkerIsTerminatedForTestingReply = 525
    , WebSWServerConnection_SetThrottleState = 526
    , WebSWServerConnection_StoreRegistrationsOnDisk = 527
    , WebSWServerConnection_StoreRegistrationsOnDiskReply = 528
    , WebSWServerToContextConnection_ScriptContextFailedToStart = 529
    , WebSWServerToContextConnection_ScriptContextStarted = 530
    , WebSWServerToContextConnection_DidFinishInstall = 531
    , WebSWServerToContextConnection_DidFinishActivation = 532
    , WebSWServerToContextConnection_SetServiceWorkerHasPendingEvents = 533
    , WebSWServerToContextConnection_SkipWaiting = 534
    , WebSWServerToContextConnection_SkipWaitingReply = 535
    , WebSWServerToContextConnection_WorkerTerminated = 536
    , WebSWServerToContextConnection_FindClientByIdentifier = 537
    , WebSWServerToContextConnection_MatchAll = 538
    , WebSWServerToContextConnection_Claim = 539
    , WebSWServerToContextConnection_ClaimReply = 540
    , WebSWServerToContextConnection_SetScriptResource = 541
    , WebSWServerToContextConnection_PostMessageToServiceWorkerClient = 542
    , WebSWServerToContextConnection_DidFailHeartBeatCheck = 543
    , StorageManagerSet_ConnectToLocalStorageArea = 544
    , StorageManagerSet_ConnectToTransientLocalStorageArea = 545
    , StorageManagerSet_ConnectToSessionStorageArea = 546
    , StorageManagerSet_DisconnectFromStorageArea = 547
    , StorageManagerSet_GetValues = 548
    , StorageManagerSet_CloneSessionStorageNamespace = 549
    , StorageManagerSet_SetItem = 550
    , StorageManagerSet_RemoveItem = 551
    , StorageManagerSet_Clear = 552
    , CacheStorageEngineConnection_Reference = 553
    , CacheStorageEngineConnection_Dereference = 554
    , CacheStorageEngineConnection_Open = 555
    , CacheStorageEngineConnection_OpenReply = 556
    , CacheStorageEngineConnection_Remove = 557
    , CacheStorageEngineConnection_RemoveReply = 558
    , CacheStorageEngineConnection_Caches = 559
    , CacheStorageEngineConnection_CachesReply = 560
    , CacheStorageEngineConnection_RetrieveRecords = 561
    , CacheStorageEngineConnection_RetrieveRecordsReply = 562
    , CacheStorageEngineConnection_DeleteMatchingRecords = 563
    , CacheStorageEngineConnection_DeleteMatchingRecordsReply = 564
    , CacheStorageEngineConnection_PutRecords = 565
    , CacheStorageEngineConnection_PutRecordsReply = 566
    , CacheStorageEngineConnection_ClearMemoryRepresentation = 567
    , CacheStorageEngineConnection_ClearMemoryRepresentationReply = 568
    , CacheStorageEngineConnection_EngineRepresentation = 569
    , CacheStorageEngineConnection_EngineRepresentationReply = 570
    , NetworkMDNSRegister_UnregisterMDNSNames = 571
    , NetworkMDNSRegister_RegisterMDNSName = 572
    , NetworkRTCMonitor_StartUpdatingIfNeeded = 573
    , NetworkRTCMonitor_StopUpdating = 574
    , NetworkRTCProvider_CreateUDPSocket = 575
    , NetworkRTCProvider_CreateServerTCPSocket = 576
    , NetworkRTCProvider_CreateClientTCPSocket = 577
    , NetworkRTCProvider_WrapNewTCPConnection = 578
    , NetworkRTCProvider_CreateResolver = 579
    , NetworkRTCProvider_StopResolver = 580
    , NetworkRTCSocket_SendTo = 581
    , NetworkRTCSocket_Close = 582
    , NetworkRTCSocket_SetOption = 583
    , PluginControllerProxy_GeometryDidChange = 584
    , PluginControllerProxy_VisibilityDidChange = 585
    , PluginControllerProxy_FrameDidFinishLoading = 586
    , PluginControllerProxy_FrameDidFail = 587
    , PluginControllerProxy_DidEvaluateJavaScript = 588
    , PluginControllerProxy_StreamWillSendRequest = 589
    , PluginControllerProxy_StreamDidReceiveResponse = 590
    , PluginControllerProxy_StreamDidReceiveData = 591
    , PluginControllerProxy_StreamDidFinishLoading = 592
    , PluginControllerProxy_StreamDidFail = 593
    , PluginControllerProxy_ManualStreamDidReceiveResponse = 594
    , PluginControllerProxy_ManualStreamDidReceiveData = 595
    , PluginControllerProxy_ManualStreamDidFinishLoading = 596
    , PluginControllerProxy_ManualStreamDidFail = 597
    , PluginControllerProxy_HandleMouseEvent = 598
    , PluginControllerProxy_HandleWheelEvent = 599
    , PluginControllerProxy_HandleMouseEnterEvent = 600
    , PluginControllerProxy_HandleMouseLeaveEvent = 601
    , PluginControllerProxy_HandleKeyboardEvent = 602
    , PluginControllerProxy_HandleEditingCommand = 603
    , PluginControllerProxy_IsEditingCommandEnabled = 604
    , PluginControllerProxy_HandlesPageScaleFactor = 605
    , PluginControllerProxy_RequiresUnifiedScaleFactor = 606
    , PluginControllerProxy_SetFocus = 607
    , PluginControllerProxy_DidUpdate = 608
    , PluginControllerProxy_PaintEntirePlugin = 609
    , PluginControllerProxy_GetPluginScriptableNPObject = 610
    , PluginControllerProxy_WindowFocusChanged = 611
    , PluginControllerProxy_WindowVisibilityChanged = 612
#if PLATFORM(COCOA)
    , PluginControllerProxy_SendComplexTextInput = 613
#endif
#if PLATFORM(COCOA)
    , PluginControllerProxy_WindowAndViewFramesChanged = 614
#endif
#if PLATFORM(COCOA)
    , PluginControllerProxy_SetLayerHostingMode = 615
#endif
    , PluginControllerProxy_SupportsSnapshotting = 616
    , PluginControllerProxy_Snapshot = 617
    , PluginControllerProxy_StorageBlockingStateChanged = 618
    , PluginControllerProxy_PrivateBrowsingStateChanged = 619
    , PluginControllerProxy_GetFormValue = 620
    , PluginControllerProxy_MutedStateChanged = 621
    , PluginProcess_InitializePluginProcess = 622
    , PluginProcess_CreateWebProcessConnection = 623
    , PluginProcess_GetSitesWithData = 624
    , PluginProcess_DeleteWebsiteData = 625
    , PluginProcess_DeleteWebsiteDataForHostNames = 626
#if PLATFORM(COCOA)
    , PluginProcess_SetQOS = 627
#endif
    , WebProcessConnection_CreatePlugin = 628
    , WebProcessConnection_CreatePluginAsynchronously = 629
    , WebProcessConnection_DestroyPlugin = 630
    , AuxiliaryProcess_ShutDown = 631
    , AuxiliaryProcess_SetProcessSuppressionEnabled = 632
#if OS(LINUX)
    , AuxiliaryProcess_DidReceiveMemoryPressureEvent = 633
#endif
    , WebConnection_HandleMessage = 634
    , AuthenticationManager_CompleteAuthenticationChallenge = 635
    , NPObjectMessageReceiver_Deallocate = 636
    , NPObjectMessageReceiver_HasMethod = 637
    , NPObjectMessageReceiver_Invoke = 638
    , NPObjectMessageReceiver_InvokeDefault = 639
    , NPObjectMessageReceiver_HasProperty = 640
    , NPObjectMessageReceiver_GetProperty = 641
    , NPObjectMessageReceiver_SetProperty = 642
    , NPObjectMessageReceiver_RemoveProperty = 643
    , NPObjectMessageReceiver_Enumerate = 644
    , NPObjectMessageReceiver_Construct = 645
    , DrawingAreaProxy_EnterAcceleratedCompositingMode = 646
    , DrawingAreaProxy_UpdateAcceleratedCompositingMode = 647
    , DrawingAreaProxy_DidFirstLayerFlush = 648
    , DrawingAreaProxy_DispatchPresentationCallbacksAfterFlushingLayers = 649
#if PLATFORM(COCOA)
    , DrawingAreaProxy_DidUpdateGeometry = 650
#endif
#if USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER)
    , DrawingAreaProxy_Update = 651
#endif
#if USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER)
    , DrawingAreaProxy_DidUpdateBackingStoreState = 652
#endif
#if USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER)
    , DrawingAreaProxy_ExitAcceleratedCompositingMode = 653
#endif
    , VisitedLinkStore_AddVisitedLinkHashFromPage = 654
    , WebCookieManagerProxy_CookiesDidChange = 655
    , WebFullScreenManagerProxy_SupportsFullScreen = 656
    , WebFullScreenManagerProxy_EnterFullScreen = 657
    , WebFullScreenManagerProxy_ExitFullScreen = 658
    , WebFullScreenManagerProxy_BeganEnterFullScreen = 659
    , WebFullScreenManagerProxy_BeganExitFullScreen = 660
    , WebFullScreenManagerProxy_Close = 661
    , WebGeolocationManagerProxy_StartUpdating = 662
    , WebGeolocationManagerProxy_StopUpdating = 663
    , WebGeolocationManagerProxy_SetEnableHighAccuracy = 664
    , WebPageProxy_CreateNewPage = 665
    , WebPageProxy_ShowPage = 666
    , WebPageProxy_ClosePage = 667
    , WebPageProxy_RunJavaScriptAlert = 668
    , WebPageProxy_RunJavaScriptConfirm = 669
    , WebPageProxy_RunJavaScriptPrompt = 670
    , WebPageProxy_MouseDidMoveOverElement = 671
#if ENABLE(NETSCAPE_PLUGIN_API)
    , WebPageProxy_UnavailablePluginButtonClicked = 672
#endif
#if ENABLE(WEBGL)
    , WebPageProxy_WebGLPolicyForURL = 673
#endif
#if ENABLE(WEBGL)
    , WebPageProxy_ResolveWebGLPolicyForURL = 674
#endif
    , WebPageProxy_DidChangeViewportProperties = 675
    , WebPageProxy_DidReceiveEvent = 676
    , WebPageProxy_SetCursor = 677
    , WebPageProxy_SetCursorHiddenUntilMouseMoves = 678
    , WebPageProxy_SetStatusText = 679
    , WebPageProxy_SetFocus = 680
    , WebPageProxy_TakeFocus = 681
    , WebPageProxy_FocusedFrameChanged = 682
    , WebPageProxy_SetRenderTreeSize = 683
    , WebPageProxy_SetToolbarsAreVisible = 684
    , WebPageProxy_GetToolbarsAreVisible = 685
    , WebPageProxy_SetMenuBarIsVisible = 686
    , WebPageProxy_GetMenuBarIsVisible = 687
    , WebPageProxy_SetStatusBarIsVisible = 688
    , WebPageProxy_GetStatusBarIsVisible = 689
    , WebPageProxy_SetIsResizable = 690
    , WebPageProxy_SetWindowFrame = 691
    , WebPageProxy_GetWindowFrame = 692
    , WebPageProxy_ScreenToRootView = 693
    , WebPageProxy_RootViewToScreen = 694
    , WebPageProxy_AccessibilityScreenToRootView = 695
    , WebPageProxy_RootViewToAccessibilityScreen = 696
#if PLATFORM(COCOA)
    , WebPageProxy_ShowValidationMessage = 697
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_HideValidationMessage = 698
#endif
    , WebPageProxy_RunBeforeUnloadConfirmPanel = 699
    , WebPageProxy_PageDidScroll = 700
    , WebPageProxy_RunOpenPanel = 701
    , WebPageProxy_ShowShareSheet = 702
    , WebPageProxy_ShowShareSheetReply = 703
    , WebPageProxy_PrintFrame = 704
    , WebPageProxy_RunModal = 705
    , WebPageProxy_NotifyScrollerThumbIsVisibleInRect = 706
    , WebPageProxy_RecommendedScrollbarStyleDidChange = 707
    , WebPageProxy_DidChangeScrollbarsForMainFrame = 708
    , WebPageProxy_DidChangeScrollOffsetPinningForMainFrame = 709
    , WebPageProxy_DidChangePageCount = 710
    , WebPageProxy_PageExtendedBackgroundColorDidChange = 711
#if ENABLE(NETSCAPE_PLUGIN_API)
    , WebPageProxy_DidFailToInitializePlugin = 712
#endif
#if ENABLE(NETSCAPE_PLUGIN_API)
    , WebPageProxy_DidBlockInsecurePluginVersion = 713
#endif
    , WebPageProxy_SetCanShortCircuitHorizontalWheelEvents = 714
    , WebPageProxy_DidChangeContentSize = 715
    , WebPageProxy_DidChangeIntrinsicContentSize = 716
#if ENABLE(INPUT_TYPE_COLOR)
    , WebPageProxy_ShowColorPicker = 717
#endif
#if ENABLE(INPUT_TYPE_COLOR)
    , WebPageProxy_SetColorPickerColor = 718
#endif
#if ENABLE(INPUT_TYPE_COLOR)
    , WebPageProxy_EndColorPicker = 719
#endif
#if ENABLE(DATALIST_ELEMENT)
    , WebPageProxy_ShowDataListSuggestions = 720
#endif
#if ENABLE(DATALIST_ELEMENT)
    , WebPageProxy_HandleKeydownInDataList = 721
#endif
#if ENABLE(DATALIST_ELEMENT)
    , WebPageProxy_EndDataListSuggestions = 722
#endif
    , WebPageProxy_DecidePolicyForResponse = 723
    , WebPageProxy_DecidePolicyForNavigationActionAsync = 724
    , WebPageProxy_DecidePolicyForNavigationActionSync = 725
    , WebPageProxy_DecidePolicyForNewWindowAction = 726
    , WebPageProxy_UnableToImplementPolicy = 727
    , WebPageProxy_DidChangeProgress = 728
    , WebPageProxy_DidFinishProgress = 729
    , WebPageProxy_DidStartProgress = 730
    , WebPageProxy_SetNetworkRequestsInProgress = 731
    , WebPageProxy_DidCreateMainFrame = 732
    , WebPageProxy_DidCreateSubframe = 733
    , WebPageProxy_DidCreateWindow = 734
    , WebPageProxy_DidStartProvisionalLoadForFrame = 735
    , WebPageProxy_DidReceiveServerRedirectForProvisionalLoadForFrame = 736
    , WebPageProxy_WillPerformClientRedirectForFrame = 737
    , WebPageProxy_DidCancelClientRedirectForFrame = 738
    , WebPageProxy_DidChangeProvisionalURLForFrame = 739
    , WebPageProxy_DidFailProvisionalLoadForFrame = 740
    , WebPageProxy_DidCommitLoadForFrame = 741
    , WebPageProxy_DidFailLoadForFrame = 742
    , WebPageProxy_DidFinishDocumentLoadForFrame = 743
    , WebPageProxy_DidFinishLoadForFrame = 744
    , WebPageProxy_DidFirstLayoutForFrame = 745
    , WebPageProxy_DidFirstVisuallyNonEmptyLayoutForFrame = 746
    , WebPageProxy_DidReachLayoutMilestone = 747
    , WebPageProxy_DidReceiveTitleForFrame = 748
    , WebPageProxy_DidDisplayInsecureContentForFrame = 749
    , WebPageProxy_DidRunInsecureContentForFrame = 750
    , WebPageProxy_DidDetectXSSForFrame = 751
    , WebPageProxy_DidSameDocumentNavigationForFrame = 752
    , WebPageProxy_DidChangeMainDocument = 753
    , WebPageProxy_DidExplicitOpenForFrame = 754
    , WebPageProxy_DidDestroyNavigation = 755
    , WebPageProxy_MainFramePluginHandlesPageScaleGestureDidChange = 756
    , WebPageProxy_DidNavigateWithNavigationData = 757
    , WebPageProxy_DidPerformClientRedirect = 758
    , WebPageProxy_DidPerformServerRedirect = 759
    , WebPageProxy_DidUpdateHistoryTitle = 760
    , WebPageProxy_DidFinishLoadingDataForCustomContentProvider = 761
    , WebPageProxy_WillSubmitForm = 762
    , WebPageProxy_VoidCallback = 763
    , WebPageProxy_DataCallback = 764
    , WebPageProxy_ImageCallback = 765
    , WebPageProxy_StringCallback = 766
    , WebPageProxy_BoolCallback = 767
    , WebPageProxy_InvalidateStringCallback = 768
    , WebPageProxy_ScriptValueCallback = 769
    , WebPageProxy_ComputedPagesCallback = 770
    , WebPageProxy_ValidateCommandCallback = 771
    , WebPageProxy_EditingRangeCallback = 772
    , WebPageProxy_UnsignedCallback = 773
    , WebPageProxy_RectForCharacterRangeCallback = 774
#if ENABLE(APPLICATION_MANIFEST)
    , WebPageProxy_ApplicationManifestCallback = 775
#endif
#if PLATFORM(MAC)
    , WebPageProxy_AttributedStringForCharacterRangeCallback = 776
#endif
#if PLATFORM(MAC)
    , WebPageProxy_FontAtSelectionCallback = 777
#endif
    , WebPageProxy_FontAttributesCallback = 778
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_GestureCallback = 779
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_TouchesCallback = 780
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_SelectionContextCallback = 781
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_InterpretKeyEvent = 782
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_DidReceivePositionInformation = 783
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_SaveImageToLibrary = 784
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ShowPlaybackTargetPicker = 785
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_CommitPotentialTapFailed = 786
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_DidNotHandleTapAsClick = 787
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_DidCompleteSyntheticClick = 788
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_DisableDoubleTapGesturesDuringTapIfNecessary = 789
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_HandleSmartMagnificationInformationForPotentialTap = 790
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_SelectionRectsCallback = 791
#endif
#if ENABLE(DATA_DETECTION)
    , WebPageProxy_SetDataDetectionResult = 792
#endif
#if PLATFORM(GTK)
    , WebPageProxy_PrintFinishedCallback = 793
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_DrawToPDFCallback = 794
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_NowPlayingInfoCallback = 795
#endif
    , WebPageProxy_FindStringCallback = 796
    , WebPageProxy_PageScaleFactorDidChange = 797
    , WebPageProxy_PluginScaleFactorDidChange = 798
    , WebPageProxy_PluginZoomFactorDidChange = 799
#if USE(ATK)
    , WebPageProxy_BindAccessibilityTree = 800
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebPageProxy_SetInputMethodState = 801
#endif
    , WebPageProxy_BackForwardAddItem = 802
    , WebPageProxy_BackForwardGoToItem = 803
    , WebPageProxy_BackForwardItemAtIndex = 804
    , WebPageProxy_BackForwardListCounts = 805
    , WebPageProxy_BackForwardClear = 806
    , WebPageProxy_WillGoToBackForwardListItem = 807
    , WebPageProxy_RegisterEditCommandForUndo = 808
    , WebPageProxy_ClearAllEditCommands = 809
    , WebPageProxy_RegisterInsertionUndoGrouping = 810
    , WebPageProxy_CanUndoRedo = 811
    , WebPageProxy_ExecuteUndoRedo = 812
    , WebPageProxy_LogDiagnosticMessage = 813
    , WebPageProxy_LogDiagnosticMessageWithResult = 814
    , WebPageProxy_LogDiagnosticMessageWithValue = 815
    , WebPageProxy_LogDiagnosticMessageWithEnhancedPrivacy = 816
    , WebPageProxy_LogDiagnosticMessageWithValueDictionary = 817
    , WebPageProxy_LogScrollingEvent = 818
    , WebPageProxy_EditorStateChanged = 819
    , WebPageProxy_CompositionWasCanceled = 820
    , WebPageProxy_SetHasHadSelectionChangesFromUserInteraction = 821
#if HAVE(TOUCH_BAR)
    , WebPageProxy_SetIsTouchBarUpdateSupressedForHiddenContentEditable = 822
#endif
#if HAVE(TOUCH_BAR)
    , WebPageProxy_SetIsNeverRichlyEditableForTouchBar = 823
#endif
    , WebPageProxy_RequestDOMPasteAccess = 824
    , WebPageProxy_DidCountStringMatches = 825
    , WebPageProxy_SetTextIndicator = 826
    , WebPageProxy_ClearTextIndicator = 827
    , WebPageProxy_DidFindString = 828
    , WebPageProxy_DidFailToFindString = 829
    , WebPageProxy_DidFindStringMatches = 830
    , WebPageProxy_DidGetImageForFindMatch = 831
    , WebPageProxy_ShowPopupMenu = 832
    , WebPageProxy_HidePopupMenu = 833
#if ENABLE(CONTEXT_MENUS)
    , WebPageProxy_ShowContextMenu = 834
#endif
    , WebPageProxy_ExceededDatabaseQuota = 835
    , WebPageProxy_ReachedApplicationCacheOriginQuota = 836
    , WebPageProxy_RequestGeolocationPermissionForFrame = 837
    , WebPageProxy_RevokeGeolocationAuthorizationToken = 838
#if ENABLE(MEDIA_STREAM)
    , WebPageProxy_RequestUserMediaPermissionForFrame = 839
#endif
#if ENABLE(MEDIA_STREAM)
    , WebPageProxy_EnumerateMediaDevicesForFrame = 840
    , WebPageProxy_EnumerateMediaDevicesForFrameReply = 841
#endif
#if ENABLE(MEDIA_STREAM)
    , WebPageProxy_BeginMonitoringCaptureDevices = 842
#endif
    , WebPageProxy_RequestNotificationPermission = 843
    , WebPageProxy_ShowNotification = 844
    , WebPageProxy_CancelNotification = 845
    , WebPageProxy_ClearNotifications = 846
    , WebPageProxy_DidDestroyNotification = 847
#if USE(UNIFIED_TEXT_CHECKING)
    , WebPageProxy_CheckTextOfParagraph = 848
#endif
    , WebPageProxy_CheckSpellingOfString = 849
    , WebPageProxy_CheckGrammarOfString = 850
    , WebPageProxy_SpellingUIIsShowing = 851
    , WebPageProxy_UpdateSpellingUIWithMisspelledWord = 852
    , WebPageProxy_UpdateSpellingUIWithGrammarString = 853
    , WebPageProxy_GetGuessesForWord = 854
    , WebPageProxy_LearnWord = 855
    , WebPageProxy_IgnoreWord = 856
    , WebPageProxy_RequestCheckingOfString = 857
#if ENABLE(DRAG_SUPPORT)
    , WebPageProxy_DidPerformDragControllerAction = 858
#endif
#if ENABLE(DRAG_SUPPORT)
    , WebPageProxy_DidEndDragging = 859
#endif
#if PLATFORM(COCOA) && ENABLE(DRAG_SUPPORT)
    , WebPageProxy_StartDrag = 860
#endif
#if PLATFORM(COCOA) && ENABLE(DRAG_SUPPORT)
    , WebPageProxy_SetPromisedDataForImage = 861
#endif
#if PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
    , WebPageProxy_StartDrag = 862
#endif
#if ENABLE(DRAG_SUPPORT)
    , WebPageProxy_DidPerformDragOperation = 863
#endif
#if ENABLE(DATA_INTERACTION)
    , WebPageProxy_DidHandleDragStartRequest = 864
#endif
#if ENABLE(DATA_INTERACTION)
    , WebPageProxy_DidHandleAdditionalDragItemsRequest = 865
#endif
#if ENABLE(DATA_INTERACTION)
    , WebPageProxy_WillReceiveEditDragSnapshot = 866
#endif
#if ENABLE(DATA_INTERACTION)
    , WebPageProxy_DidReceiveEditDragSnapshot = 867
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_DidPerformDictionaryLookup = 868
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_ExecuteSavedCommandBySelector = 869
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_RegisterWebProcessAccessibilityToken = 870
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_PluginFocusOrWindowFocusChanged = 871
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_SetPluginComplexTextInputState = 872
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_GetIsSpeaking = 873
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_Speak = 874
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_StopSpeaking = 875
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_MakeFirstResponder = 876
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_AssistiveTechnologyMakeFirstResponder = 877
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_SearchWithSpotlight = 878
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_SearchTheWeb = 879
#endif
#if HAVE(TOUCH_BAR)
    , WebPageProxy_TouchBarMenuDataChanged = 880
#endif
#if HAVE(TOUCH_BAR)
    , WebPageProxy_TouchBarMenuItemDataAdded = 881
#endif
#if HAVE(TOUCH_BAR)
    , WebPageProxy_TouchBarMenuItemDataRemoved = 882
#endif
#if USE(APPKIT)
    , WebPageProxy_SubstitutionsPanelIsShowing = 883
#endif
#if USE(AUTOMATIC_TEXT_REPLACEMENT)
    , WebPageProxy_toggleSmartInsertDelete = 884
#endif
#if USE(AUTOMATIC_TEXT_REPLACEMENT)
    , WebPageProxy_toggleAutomaticQuoteSubstitution = 885
#endif
#if USE(AUTOMATIC_TEXT_REPLACEMENT)
    , WebPageProxy_toggleAutomaticLinkDetection = 886
#endif
#if USE(AUTOMATIC_TEXT_REPLACEMENT)
    , WebPageProxy_toggleAutomaticDashSubstitution = 887
#endif
#if USE(AUTOMATIC_TEXT_REPLACEMENT)
    , WebPageProxy_toggleAutomaticTextReplacement = 888
#endif
#if PLATFORM(MAC)
    , WebPageProxy_ShowCorrectionPanel = 889
#endif
#if PLATFORM(MAC)
    , WebPageProxy_DismissCorrectionPanel = 890
#endif
#if PLATFORM(MAC)
    , WebPageProxy_DismissCorrectionPanelSoon = 891
#endif
#if PLATFORM(MAC)
    , WebPageProxy_RecordAutocorrectionResponse = 892
#endif
#if PLATFORM(MAC)
    , WebPageProxy_SetEditableElementIsFocused = 893
#endif
#if USE(DICTATION_ALTERNATIVES)
    , WebPageProxy_ShowDictationAlternativeUI = 894
#endif
#if USE(DICTATION_ALTERNATIVES)
    , WebPageProxy_RemoveDictationAlternatives = 895
#endif
#if USE(DICTATION_ALTERNATIVES)
    , WebPageProxy_DictationAlternatives = 896
#endif
#if PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
    , WebPageProxy_CreatePluginContainer = 897
#endif
#if PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
    , WebPageProxy_WindowedPluginGeometryDidChange = 898
#endif
#if PLATFORM(X11) && ENABLE(NETSCAPE_PLUGIN_API)
    , WebPageProxy_WindowedPluginVisibilityDidChange = 899
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_CouldNotRestorePageState = 900
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_RestorePageState = 901
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_RestorePageCenterAndScale = 902
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_DidGetTapHighlightGeometries = 903
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ElementDidFocus = 904
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ElementDidBlur = 905
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_UpdateInputContextAfterBlurringAndRefocusingElement = 906
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_FocusedElementDidChangeInputMode = 907
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ScrollingNodeScrollWillStartScroll = 908
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ScrollingNodeScrollDidEndScroll = 909
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ShowInspectorHighlight = 910
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_HideInspectorHighlight = 911
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_FocusedElementInformationCallback = 912
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ShowInspectorIndication = 913
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_HideInspectorIndication = 914
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_EnableInspectorNodeSearch = 915
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_DisableInspectorNodeSearch = 916
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_UpdateStringForFind = 917
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_HandleAutocorrectionContext = 918
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPageProxy_ShowDataDetectorsUIForPositionInformation = 919
#endif
    , WebPageProxy_DidChangeInspectorFrontendCount = 920
    , WebPageProxy_CreateInspectorTarget = 921
    , WebPageProxy_DestroyInspectorTarget = 922
    , WebPageProxy_SendMessageToInspectorFrontend = 923
    , WebPageProxy_SaveRecentSearches = 924
    , WebPageProxy_LoadRecentSearches = 925
    , WebPageProxy_SavePDFToFileInDownloadsFolder = 926
#if PLATFORM(COCOA)
    , WebPageProxy_SavePDFToTemporaryFolderAndOpenWithNativeApplication = 927
#endif
#if PLATFORM(COCOA)
    , WebPageProxy_OpenPDFFromTemporaryFolderWithNativeApplication = 928
#endif
#if ENABLE(PDFKIT_PLUGIN)
    , WebPageProxy_ShowPDFContextMenu = 929
#endif
#if ENABLE(NETSCAPE_PLUGIN_API)
    , WebPageProxy_FindPlugin = 930
#endif
    , WebPageProxy_DidUpdateActivityState = 931
#if ENABLE(WEB_CRYPTO)
    , WebPageProxy_WrapCryptoKey = 932
#endif
#if ENABLE(WEB_CRYPTO)
    , WebPageProxy_UnwrapCryptoKey = 933
#endif
#if (ENABLE(TELEPHONE_NUMBER_DETECTION) && PLATFORM(MAC))
    , WebPageProxy_ShowTelephoneNumberMenu = 934
#endif
#if USE(QUICK_LOOK)
    , WebPageProxy_DidStartLoadForQuickLookDocumentInMainFrame = 935
#endif
#if USE(QUICK_LOOK)
    , WebPageProxy_DidFinishLoadForQuickLookDocumentInMainFrame = 936
#endif
#if USE(QUICK_LOOK)
    , WebPageProxy_RequestPasswordForQuickLookDocumentInMainFrame = 937
    , WebPageProxy_RequestPasswordForQuickLookDocumentInMainFrameReply = 938
#endif
#if ENABLE(CONTENT_FILTERING)
    , WebPageProxy_ContentFilterDidBlockLoadForFrame = 939
#endif
    , WebPageProxy_IsPlayingMediaDidChange = 940
    , WebPageProxy_HandleAutoplayEvent = 941
#if ENABLE(MEDIA_SESSION)
    , WebPageProxy_HasMediaSessionWithActiveMediaElementsDidChange = 942
#endif
#if ENABLE(MEDIA_SESSION)
    , WebPageProxy_MediaSessionMetadataDidChange = 943
#endif
#if ENABLE(MEDIA_SESSION)
    , WebPageProxy_FocusedContentMediaElementDidChange = 944
#endif
#if PLATFORM(MAC)
    , WebPageProxy_DidPerformImmediateActionHitTest = 945
#endif
    , WebPageProxy_HandleMessage = 946
    , WebPageProxy_HandleSynchronousMessage = 947
    , WebPageProxy_HandleAutoFillButtonClick = 948
    , WebPageProxy_DidResignInputElementStrongPasswordAppearance = 949
    , WebPageProxy_ContentRuleListNotification = 950
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPageProxy_AddPlaybackTargetPickerClient = 951
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPageProxy_RemovePlaybackTargetPickerClient = 952
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPageProxy_ShowPlaybackTargetPicker = 953
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPageProxy_PlaybackTargetPickerClientStateDidChange = 954
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPageProxy_SetMockMediaPlaybackTargetPickerEnabled = 955
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPageProxy_SetMockMediaPlaybackTargetPickerState = 956
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPageProxy_MockMediaPlaybackTargetPickerDismissPopup = 957
#endif
#if ENABLE(VIDEO_PRESENTATION_MODE)
    , WebPageProxy_SetMockVideoPresentationModeEnabled = 958
#endif
#if ENABLE(POINTER_LOCK)
    , WebPageProxy_RequestPointerLock = 959
#endif
#if ENABLE(POINTER_LOCK)
    , WebPageProxy_RequestPointerUnlock = 960
#endif
    , WebPageProxy_DidFailToSuspendAfterProcessSwap = 961
    , WebPageProxy_DidSuspendAfterProcessSwap = 962
    , WebPageProxy_ImageOrMediaDocumentSizeChanged = 963
    , WebPageProxy_UseFixedLayoutDidChange = 964
    , WebPageProxy_FixedLayoutSizeDidChange = 965
#if ENABLE(VIDEO) && USE(GSTREAMER)
    , WebPageProxy_RequestInstallMissingMediaPlugins = 966
#endif
    , WebPageProxy_DidRestoreScrollPosition = 967
    , WebPageProxy_GetLoadDecisionForIcon = 968
    , WebPageProxy_FinishedLoadingIcon = 969
#if PLATFORM(MAC)
    , WebPageProxy_DidHandleAcceptedCandidate = 970
#endif
    , WebPageProxy_SetIsUsingHighPerformanceWebGL = 971
    , WebPageProxy_StartURLSchemeTask = 972
    , WebPageProxy_StopURLSchemeTask = 973
    , WebPageProxy_LoadSynchronousURLSchemeTask = 974
#if ENABLE(DEVICE_ORIENTATION)
    , WebPageProxy_ShouldAllowDeviceOrientationAndMotionAccess = 975
    , WebPageProxy_ShouldAllowDeviceOrientationAndMotionAccessReply = 976
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_RegisterAttachmentIdentifierFromData = 977
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_RegisterAttachmentIdentifierFromFilePath = 978
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_RegisterAttachmentIdentifier = 979
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_RegisterAttachmentsFromSerializedData = 980
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_CloneAttachmentData = 981
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_DidInsertAttachmentWithIdentifier = 982
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_DidRemoveAttachmentWithIdentifier = 983
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_SerializedAttachmentDataForIdentifiers = 984
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPageProxy_WritePromisedAttachmentToPasteboard = 985
#endif
    , WebPageProxy_SignedPublicKeyAndChallengeString = 986
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPageProxy_SpeechSynthesisVoiceList = 987
#endif
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPageProxy_SpeechSynthesisSpeak = 988
    , WebPageProxy_SpeechSynthesisSpeakReply = 989
#endif
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPageProxy_SpeechSynthesisSetFinishedCallback = 990
    , WebPageProxy_SpeechSynthesisSetFinishedCallbackReply = 991
#endif
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPageProxy_SpeechSynthesisCancel = 992
#endif
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPageProxy_SpeechSynthesisPause = 993
    , WebPageProxy_SpeechSynthesisPauseReply = 994
#endif
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPageProxy_SpeechSynthesisResume = 995
    , WebPageProxy_SpeechSynthesisResumeReply = 996
#endif
    , WebPageProxy_ConfigureLoggingChannel = 997
#if PLATFORM(GTK)
    , WebPageProxy_ShowEmojiPicker = 998
    , WebPageProxy_ShowEmojiPickerReply = 999
#endif
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
    , WebPageProxy_DidCreateContextForVisibilityPropagation = 1000
#endif
#if ENABLE(WEB_AUTHN)
    , WebPageProxy_SetMockWebAuthenticationConfiguration = 1001
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebPageProxy_SendMessageToWebView = 1002
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebPageProxy_SendMessageToWebViewWithReply = 1003
    , WebPageProxy_SendMessageToWebViewWithReplyReply = 1004
#endif
    , WebPageProxy_DidFindTextManipulationItems = 1005
#if ENABLE(MEDIA_USAGE)
    , WebPageProxy_AddMediaUsageManagerSession = 1006
#endif
#if ENABLE(MEDIA_USAGE)
    , WebPageProxy_UpdateMediaUsageManagerSessionState = 1007
#endif
#if ENABLE(MEDIA_USAGE)
    , WebPageProxy_RemoveMediaUsageManagerSession = 1008
#endif
    , WebPageProxy_SetHasExecutedAppBoundBehaviorBeforeNavigation = 1009
#if PLATFORM(IOS_FAMILY)
    , WebPasteboardProxy_WriteURLToPasteboard = 1010
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPasteboardProxy_WriteWebContentToPasteboard = 1011
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPasteboardProxy_WriteImageToPasteboard = 1012
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPasteboardProxy_WriteStringToPasteboard = 1013
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPasteboardProxy_UpdateSupportedTypeIdentifiers = 1014
#endif
    , WebPasteboardProxy_WriteCustomData = 1015
    , WebPasteboardProxy_TypesSafeForDOMToReadAndWrite = 1016
    , WebPasteboardProxy_AllPasteboardItemInfo = 1017
    , WebPasteboardProxy_InformationForItemAtIndex = 1018
    , WebPasteboardProxy_GetPasteboardItemsCount = 1019
    , WebPasteboardProxy_ReadStringFromPasteboard = 1020
    , WebPasteboardProxy_ReadURLFromPasteboard = 1021
    , WebPasteboardProxy_ReadBufferFromPasteboard = 1022
    , WebPasteboardProxy_ContainsStringSafeForDOMToReadForType = 1023
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetNumberOfFiles = 1024
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardTypes = 1025
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardPathnamesForType = 1026
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardStringForType = 1027
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardStringsForType = 1028
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardBufferForType = 1029
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardChangeCount = 1030
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardColor = 1031
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_GetPasteboardURL = 1032
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_AddPasteboardTypes = 1033
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_SetPasteboardTypes = 1034
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_SetPasteboardURL = 1035
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_SetPasteboardColor = 1036
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_SetPasteboardStringForType = 1037
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_SetPasteboardBufferForType = 1038
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_ContainsURLStringSuitableForLoading = 1039
#endif
#if PLATFORM(COCOA)
    , WebPasteboardProxy_URLStringSuitableForLoading = 1040
#endif
#if PLATFORM(GTK)
    , WebPasteboardProxy_GetTypes = 1041
#endif
#if PLATFORM(GTK)
    , WebPasteboardProxy_ReadText = 1042
#endif
#if PLATFORM(GTK)
    , WebPasteboardProxy_ReadFilePaths = 1043
#endif
#if PLATFORM(GTK)
    , WebPasteboardProxy_ReadBuffer = 1044
#endif
#if PLATFORM(GTK)
    , WebPasteboardProxy_WriteToClipboard = 1045
#endif
#if PLATFORM(GTK)
    , WebPasteboardProxy_ClearClipboard = 1046
#endif
#if USE(LIBWPE)
    , WebPasteboardProxy_GetPasteboardTypes = 1047
#endif
#if USE(LIBWPE)
    , WebPasteboardProxy_WriteWebContentToPasteboard = 1048
#endif
#if USE(LIBWPE)
    , WebPasteboardProxy_WriteStringToPasteboard = 1049
#endif
    , WebProcessPool_HandleMessage = 1050
    , WebProcessPool_HandleSynchronousMessage = 1051
#if ENABLE(GAMEPAD)
    , WebProcessPool_StartedUsingGamepads = 1052
#endif
#if ENABLE(GAMEPAD)
    , WebProcessPool_StoppedUsingGamepads = 1053
#endif
    , WebProcessPool_ReportWebContentCPUTime = 1054
    , WebProcessProxy_UpdateBackForwardItem = 1055
    , WebProcessProxy_DidDestroyFrame = 1056
    , WebProcessProxy_DidDestroyUserGestureToken = 1057
    , WebProcessProxy_ShouldTerminate = 1058
    , WebProcessProxy_EnableSuddenTermination = 1059
    , WebProcessProxy_DisableSuddenTermination = 1060
#if ENABLE(NETSCAPE_PLUGIN_API)
    , WebProcessProxy_GetPlugins = 1061
#endif
#if ENABLE(NETSCAPE_PLUGIN_API)
    , WebProcessProxy_GetPluginProcessConnection = 1062
#endif
    , WebProcessProxy_GetNetworkProcessConnection = 1063
#if ENABLE(GPU_PROCESS)
    , WebProcessProxy_GetGPUProcessConnection = 1064
#endif
    , WebProcessProxy_SetIsHoldingLockedFiles = 1065
    , WebProcessProxy_DidExceedActiveMemoryLimit = 1066
    , WebProcessProxy_DidExceedInactiveMemoryLimit = 1067
    , WebProcessProxy_DidExceedCPULimit = 1068
    , WebProcessProxy_StopResponsivenessTimer = 1069
    , WebProcessProxy_DidReceiveMainThreadPing = 1070
    , WebProcessProxy_DidReceiveBackgroundResponsivenessPing = 1071
    , WebProcessProxy_MemoryPressureStatusChanged = 1072
    , WebProcessProxy_DidExceedInactiveMemoryLimitWhileActive = 1073
    , WebProcessProxy_DidCollectPrewarmInformation = 1074
#if PLATFORM(COCOA)
    , WebProcessProxy_CacheMediaMIMETypes = 1075
#endif
#if PLATFORM(MAC)
    , WebProcessProxy_RequestHighPerformanceGPU = 1076
#endif
#if PLATFORM(MAC)
    , WebProcessProxy_ReleaseHighPerformanceGPU = 1077
#endif
#if PLATFORM(MAC) && ENABLE(WEBPROCESS_WINDOWSERVER_BLOCKING)
    , WebProcessProxy_StartDisplayLink = 1078
#endif
#if PLATFORM(MAC) && ENABLE(WEBPROCESS_WINDOWSERVER_BLOCKING)
    , WebProcessProxy_StopDisplayLink = 1079
#endif
    , WebProcessProxy_AddPlugInAutoStartOriginHash = 1080
    , WebProcessProxy_PlugInDidReceiveUserInteraction = 1081
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebProcessProxy_SendMessageToWebContext = 1082
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebProcessProxy_SendMessageToWebContextWithReply = 1083
    , WebProcessProxy_SendMessageToWebContextWithReplyReply = 1084
#endif
    , WebProcessProxy_DidCreateSleepDisabler = 1085
    , WebProcessProxy_DidDestroySleepDisabler = 1086
    , WebAutomationSession_DidEvaluateJavaScriptFunction = 1087
    , WebAutomationSession_DidTakeScreenshot = 1088
    , DownloadProxy_DidStart = 1089
    , DownloadProxy_DidReceiveAuthenticationChallenge = 1090
    , DownloadProxy_WillSendRequest = 1091
    , DownloadProxy_DecideDestinationWithSuggestedFilenameAsync = 1092
    , DownloadProxy_DidReceiveResponse = 1093
    , DownloadProxy_DidReceiveData = 1094
    , DownloadProxy_DidCreateDestination = 1095
    , DownloadProxy_DidFinish = 1096
    , DownloadProxy_DidFail = 1097
    , DownloadProxy_DidCancel = 1098
#if HAVE(VISIBILITY_PROPAGATION_VIEW)
    , GPUProcessProxy_DidCreateContextForVisibilityPropagation = 1099
#endif
    , RemoteWebInspectorProxy_FrontendDidClose = 1100
    , RemoteWebInspectorProxy_Reopen = 1101
    , RemoteWebInspectorProxy_ResetState = 1102
    , RemoteWebInspectorProxy_BringToFront = 1103
    , RemoteWebInspectorProxy_Save = 1104
    , RemoteWebInspectorProxy_Append = 1105
    , RemoteWebInspectorProxy_SetForcedAppearance = 1106
    , RemoteWebInspectorProxy_SetSheetRect = 1107
    , RemoteWebInspectorProxy_StartWindowDrag = 1108
    , RemoteWebInspectorProxy_OpenInNewTab = 1109
    , RemoteWebInspectorProxy_ShowCertificate = 1110
    , RemoteWebInspectorProxy_SendMessageToBackend = 1111
    , WebInspectorProxy_OpenLocalInspectorFrontend = 1112
    , WebInspectorProxy_SetFrontendConnection = 1113
    , WebInspectorProxy_SendMessageToBackend = 1114
    , WebInspectorProxy_FrontendLoaded = 1115
    , WebInspectorProxy_DidClose = 1116
    , WebInspectorProxy_BringToFront = 1117
    , WebInspectorProxy_BringInspectedPageToFront = 1118
    , WebInspectorProxy_Reopen = 1119
    , WebInspectorProxy_ResetState = 1120
    , WebInspectorProxy_SetForcedAppearance = 1121
    , WebInspectorProxy_InspectedURLChanged = 1122
    , WebInspectorProxy_ShowCertificate = 1123
    , WebInspectorProxy_ElementSelectionChanged = 1124
    , WebInspectorProxy_TimelineRecordingChanged = 1125
    , WebInspectorProxy_SetDeveloperPreferenceOverride = 1126
    , WebInspectorProxy_Save = 1127
    , WebInspectorProxy_Append = 1128
    , WebInspectorProxy_AttachBottom = 1129
    , WebInspectorProxy_AttachRight = 1130
    , WebInspectorProxy_AttachLeft = 1131
    , WebInspectorProxy_Detach = 1132
    , WebInspectorProxy_AttachAvailabilityChanged = 1133
    , WebInspectorProxy_SetAttachedWindowHeight = 1134
    , WebInspectorProxy_SetAttachedWindowWidth = 1135
    , WebInspectorProxy_SetSheetRect = 1136
    , WebInspectorProxy_StartWindowDrag = 1137
    , NetworkProcessProxy_DidReceiveAuthenticationChallenge = 1138
    , NetworkProcessProxy_NegotiatedLegacyTLS = 1139
    , NetworkProcessProxy_DidNegotiateModernTLS = 1140
    , NetworkProcessProxy_DidFetchWebsiteData = 1141
    , NetworkProcessProxy_DidDeleteWebsiteData = 1142
    , NetworkProcessProxy_DidDeleteWebsiteDataForOrigins = 1143
    , NetworkProcessProxy_DidSyncAllCookies = 1144
    , NetworkProcessProxy_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply = 1145
    , NetworkProcessProxy_TerminateUnresponsiveServiceWorkerProcesses = 1146
    , NetworkProcessProxy_SetIsHoldingLockedFiles = 1147
    , NetworkProcessProxy_LogDiagnosticMessage = 1148
    , NetworkProcessProxy_LogDiagnosticMessageWithResult = 1149
    , NetworkProcessProxy_LogDiagnosticMessageWithValue = 1150
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_LogTestingEvent = 1151
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_NotifyResourceLoadStatisticsProcessed = 1152
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_NotifyWebsiteDataDeletionForRegistrableDomainsFinished = 1153
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_NotifyWebsiteDataScanForRegistrableDomainsFinished = 1154
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_NotifyResourceLoadStatisticsTelemetryFinished = 1155
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_RequestStorageAccessConfirm = 1156
    , NetworkProcessProxy_RequestStorageAccessConfirmReply = 1157
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_DeleteWebsiteDataInUIProcessForRegistrableDomains = 1158
    , NetworkProcessProxy_DeleteWebsiteDataInUIProcessForRegistrableDomainsReply = 1159
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_DidCommitCrossSiteLoadWithDataTransferFromPrevalentResource = 1160
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , NetworkProcessProxy_SetDomainsWithUserInteraction = 1161
#endif
#if ENABLE(CONTENT_EXTENSIONS)
    , NetworkProcessProxy_ContentExtensionRules = 1162
#endif
    , NetworkProcessProxy_RetrieveCacheStorageParameters = 1163
    , NetworkProcessProxy_TerminateWebProcess = 1164
#if ENABLE(SERVICE_WORKER)
    , NetworkProcessProxy_EstablishWorkerContextConnectionToNetworkProcess = 1165
    , NetworkProcessProxy_EstablishWorkerContextConnectionToNetworkProcessReply = 1166
#endif
#if ENABLE(SERVICE_WORKER)
    , NetworkProcessProxy_WorkerContextConnectionNoLongerNeeded = 1167
#endif
#if ENABLE(SERVICE_WORKER)
    , NetworkProcessProxy_RegisterServiceWorkerClientProcess = 1168
#endif
#if ENABLE(SERVICE_WORKER)
    , NetworkProcessProxy_UnregisterServiceWorkerClientProcess = 1169
#endif
    , NetworkProcessProxy_SetWebProcessHasUploads = 1170
    , NetworkProcessProxy_GetAppBoundDomains = 1171
    , NetworkProcessProxy_GetAppBoundDomainsReply = 1172
    , NetworkProcessProxy_RequestStorageSpace = 1173
    , NetworkProcessProxy_RequestStorageSpaceReply = 1174
    , NetworkProcessProxy_ResourceLoadDidSendRequest = 1175
    , NetworkProcessProxy_ResourceLoadDidPerformHTTPRedirection = 1176
    , NetworkProcessProxy_ResourceLoadDidReceiveChallenge = 1177
    , NetworkProcessProxy_ResourceLoadDidReceiveResponse = 1178
    , NetworkProcessProxy_ResourceLoadDidCompleteWithError = 1179
    , PluginProcessProxy_DidCreateWebProcessConnection = 1180
    , PluginProcessProxy_DidGetSitesWithData = 1181
    , PluginProcessProxy_DidDeleteWebsiteData = 1182
    , PluginProcessProxy_DidDeleteWebsiteDataForHostNames = 1183
#if PLATFORM(COCOA)
    , PluginProcessProxy_SetModalWindowIsShowing = 1184
#endif
#if PLATFORM(COCOA)
    , PluginProcessProxy_SetFullscreenWindowIsShowing = 1185
#endif
#if PLATFORM(COCOA)
    , PluginProcessProxy_LaunchProcess = 1186
#endif
#if PLATFORM(COCOA)
    , PluginProcessProxy_LaunchApplicationAtURL = 1187
#endif
#if PLATFORM(COCOA)
    , PluginProcessProxy_OpenURL = 1188
#endif
#if PLATFORM(COCOA)
    , PluginProcessProxy_OpenFile = 1189
#endif
    , WebUserContentControllerProxy_DidPostMessage = 1190
    , WebUserContentControllerProxy_DidPostMessageReply = 1191
    , WebProcess_InitializeWebProcess = 1192
    , WebProcess_SetWebsiteDataStoreParameters = 1193
    , WebProcess_CreateWebPage = 1194
    , WebProcess_PrewarmGlobally = 1195
    , WebProcess_PrewarmWithDomainInformation = 1196
    , WebProcess_SetCacheModel = 1197
    , WebProcess_RegisterURLSchemeAsEmptyDocument = 1198
    , WebProcess_RegisterURLSchemeAsSecure = 1199
    , WebProcess_RegisterURLSchemeAsBypassingContentSecurityPolicy = 1200
    , WebProcess_SetDomainRelaxationForbiddenForURLScheme = 1201
    , WebProcess_RegisterURLSchemeAsLocal = 1202
    , WebProcess_RegisterURLSchemeAsNoAccess = 1203
    , WebProcess_RegisterURLSchemeAsDisplayIsolated = 1204
    , WebProcess_RegisterURLSchemeAsCORSEnabled = 1205
    , WebProcess_RegisterURLSchemeAsCachePartitioned = 1206
    , WebProcess_RegisterURLSchemeAsCanDisplayOnlyIfCanRequest = 1207
    , WebProcess_SetDefaultRequestTimeoutInterval = 1208
    , WebProcess_SetAlwaysUsesComplexTextCodePath = 1209
    , WebProcess_SetShouldUseFontSmoothing = 1210
    , WebProcess_SetResourceLoadStatisticsEnabled = 1211
    , WebProcess_ClearResourceLoadStatistics = 1212
    , WebProcess_UserPreferredLanguagesChanged = 1213
    , WebProcess_FullKeyboardAccessModeChanged = 1214
    , WebProcess_DidAddPlugInAutoStartOriginHash = 1215
    , WebProcess_ResetPlugInAutoStartOriginHashes = 1216
    , WebProcess_SetPluginLoadClientPolicy = 1217
    , WebProcess_ResetPluginLoadClientPolicies = 1218
    , WebProcess_ClearPluginClientPolicies = 1219
    , WebProcess_RefreshPlugins = 1220
    , WebProcess_StartMemorySampler = 1221
    , WebProcess_StopMemorySampler = 1222
    , WebProcess_SetTextCheckerState = 1223
    , WebProcess_SetEnhancedAccessibility = 1224
    , WebProcess_GarbageCollectJavaScriptObjects = 1225
    , WebProcess_SetJavaScriptGarbageCollectorTimerEnabled = 1226
    , WebProcess_SetInjectedBundleParameter = 1227
    , WebProcess_SetInjectedBundleParameters = 1228
    , WebProcess_HandleInjectedBundleMessage = 1229
    , WebProcess_FetchWebsiteData = 1230
    , WebProcess_FetchWebsiteDataReply = 1231
    , WebProcess_DeleteWebsiteData = 1232
    , WebProcess_DeleteWebsiteDataReply = 1233
    , WebProcess_DeleteWebsiteDataForOrigins = 1234
    , WebProcess_DeleteWebsiteDataForOriginsReply = 1235
    , WebProcess_SetHiddenPageDOMTimerThrottlingIncreaseLimit = 1236
#if PLATFORM(COCOA)
    , WebProcess_SetQOS = 1237
#endif
    , WebProcess_SetMemoryCacheDisabled = 1238
#if ENABLE(SERVICE_CONTROLS)
    , WebProcess_SetEnabledServices = 1239
#endif
    , WebProcess_EnsureAutomationSessionProxy = 1240
    , WebProcess_DestroyAutomationSessionProxy = 1241
    , WebProcess_PrepareToSuspend = 1242
    , WebProcess_PrepareToSuspendReply = 1243
    , WebProcess_ProcessDidResume = 1244
    , WebProcess_MainThreadPing = 1245
    , WebProcess_BackgroundResponsivenessPing = 1246
#if ENABLE(GAMEPAD)
    , WebProcess_SetInitialGamepads = 1247
#endif
#if ENABLE(GAMEPAD)
    , WebProcess_GamepadConnected = 1248
#endif
#if ENABLE(GAMEPAD)
    , WebProcess_GamepadDisconnected = 1249
#endif
#if ENABLE(SERVICE_WORKER)
    , WebProcess_EstablishWorkerContextConnectionToNetworkProcess = 1250
    , WebProcess_EstablishWorkerContextConnectionToNetworkProcessReply = 1251
#endif
    , WebProcess_SetHasSuspendedPageProxy = 1252
    , WebProcess_SetIsInProcessCache = 1253
    , WebProcess_MarkIsNoLongerPrewarmed = 1254
    , WebProcess_GetActivePagesOriginsForTesting = 1255
    , WebProcess_GetActivePagesOriginsForTestingReply = 1256
#if PLATFORM(COCOA)
    , WebProcess_SetScreenProperties = 1257
#endif
#if PLATFORM(MAC) && ENABLE(WEBPROCESS_WINDOWSERVER_BLOCKING)
    , WebProcess_ScrollerStylePreferenceChanged = 1258
#endif
#if PLATFORM(MAC) && ENABLE(WEBPROCESS_WINDOWSERVER_BLOCKING)
    , WebProcess_DisplayConfigurationChanged = 1259
#endif
#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)
    , WebProcess_BacklightLevelDidChange = 1260
#endif
    , WebProcess_IsJITEnabled = 1261
    , WebProcess_IsJITEnabledReply = 1262
#if PLATFORM(COCOA)
    , WebProcess_SetMediaMIMETypes = 1263
#endif
#if (PLATFORM(COCOA) && ENABLE(REMOTE_INSPECTOR))
    , WebProcess_EnableRemoteWebInspector = 1264
#endif
#if ENABLE(MEDIA_STREAM)
    , WebProcess_AddMockMediaDevice = 1265
#endif
#if ENABLE(MEDIA_STREAM)
    , WebProcess_ClearMockMediaDevices = 1266
#endif
#if ENABLE(MEDIA_STREAM)
    , WebProcess_RemoveMockMediaDevice = 1267
#endif
#if ENABLE(MEDIA_STREAM)
    , WebProcess_ResetMockMediaDevices = 1268
#endif
#if (ENABLE(MEDIA_STREAM) && ENABLE(SANDBOX_EXTENSIONS))
    , WebProcess_GrantUserMediaDeviceSandboxExtensions = 1269
#endif
#if (ENABLE(MEDIA_STREAM) && ENABLE(SANDBOX_EXTENSIONS))
    , WebProcess_RevokeUserMediaDeviceSandboxExtensions = 1270
#endif
    , WebProcess_ClearCurrentModifierStateForTesting = 1271
    , WebProcess_SetBackForwardCacheCapacity = 1272
    , WebProcess_ClearCachedPage = 1273
    , WebProcess_ClearCachedPageReply = 1274
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebProcess_SendMessageToWebExtension = 1275
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , WebProcess_SeedResourceLoadStatisticsForTesting = 1276
    , WebProcess_SeedResourceLoadStatisticsForTestingReply = 1277
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , WebProcess_SetThirdPartyCookieBlockingMode = 1278
    , WebProcess_SetThirdPartyCookieBlockingModeReply = 1279
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , WebProcess_SetDomainsWithUserInteraction = 1280
#endif
#if PLATFORM(IOS)
    , WebProcess_GrantAccessToAssetServices = 1281
#endif
#if PLATFORM(IOS)
    , WebProcess_RevokeAccessToAssetServices = 1282
#endif
#if PLATFORM(COCOA)
    , WebProcess_UnblockServicesRequiredByAccessibility = 1283
#endif
#if (PLATFORM(COCOA) && ENABLE(CFPREFS_DIRECT_MODE))
    , WebProcess_NotifyPreferencesChanged = 1284
#endif
#if (PLATFORM(COCOA) && ENABLE(CFPREFS_DIRECT_MODE))
    , WebProcess_UnblockPreferenceService = 1285
#endif
#if PLATFORM(GTK) && !USE(GTK4)
    , WebProcess_SetUseSystemAppearanceForScrollbars = 1286
#endif
    , WebAutomationSessionProxy_EvaluateJavaScriptFunction = 1287
    , WebAutomationSessionProxy_ResolveChildFrameWithOrdinal = 1288
    , WebAutomationSessionProxy_ResolveChildFrameWithOrdinalReply = 1289
    , WebAutomationSessionProxy_ResolveChildFrameWithNodeHandle = 1290
    , WebAutomationSessionProxy_ResolveChildFrameWithNodeHandleReply = 1291
    , WebAutomationSessionProxy_ResolveChildFrameWithName = 1292
    , WebAutomationSessionProxy_ResolveChildFrameWithNameReply = 1293
    , WebAutomationSessionProxy_ResolveParentFrame = 1294
    , WebAutomationSessionProxy_ResolveParentFrameReply = 1295
    , WebAutomationSessionProxy_FocusFrame = 1296
    , WebAutomationSessionProxy_ComputeElementLayout = 1297
    , WebAutomationSessionProxy_ComputeElementLayoutReply = 1298
    , WebAutomationSessionProxy_SelectOptionElement = 1299
    , WebAutomationSessionProxy_SelectOptionElementReply = 1300
    , WebAutomationSessionProxy_SetFilesForInputFileUpload = 1301
    , WebAutomationSessionProxy_SetFilesForInputFileUploadReply = 1302
    , WebAutomationSessionProxy_TakeScreenshot = 1303
    , WebAutomationSessionProxy_SnapshotRectForScreenshot = 1304
    , WebAutomationSessionProxy_SnapshotRectForScreenshotReply = 1305
    , WebAutomationSessionProxy_GetCookiesForFrame = 1306
    , WebAutomationSessionProxy_GetCookiesForFrameReply = 1307
    , WebAutomationSessionProxy_DeleteCookie = 1308
    , WebAutomationSessionProxy_DeleteCookieReply = 1309
    , WebIDBConnectionToServer_DidDeleteDatabase = 1310
    , WebIDBConnectionToServer_DidOpenDatabase = 1311
    , WebIDBConnectionToServer_DidAbortTransaction = 1312
    , WebIDBConnectionToServer_DidCommitTransaction = 1313
    , WebIDBConnectionToServer_DidCreateObjectStore = 1314
    , WebIDBConnectionToServer_DidDeleteObjectStore = 1315
    , WebIDBConnectionToServer_DidRenameObjectStore = 1316
    , WebIDBConnectionToServer_DidClearObjectStore = 1317
    , WebIDBConnectionToServer_DidCreateIndex = 1318
    , WebIDBConnectionToServer_DidDeleteIndex = 1319
    , WebIDBConnectionToServer_DidRenameIndex = 1320
    , WebIDBConnectionToServer_DidPutOrAdd = 1321
    , WebIDBConnectionToServer_DidGetRecord = 1322
    , WebIDBConnectionToServer_DidGetAllRecords = 1323
    , WebIDBConnectionToServer_DidGetCount = 1324
    , WebIDBConnectionToServer_DidDeleteRecord = 1325
    , WebIDBConnectionToServer_DidOpenCursor = 1326
    , WebIDBConnectionToServer_DidIterateCursor = 1327
    , WebIDBConnectionToServer_FireVersionChangeEvent = 1328
    , WebIDBConnectionToServer_DidStartTransaction = 1329
    , WebIDBConnectionToServer_DidCloseFromServer = 1330
    , WebIDBConnectionToServer_NotifyOpenDBRequestBlocked = 1331
    , WebIDBConnectionToServer_DidGetAllDatabaseNamesAndVersions = 1332
    , WebFullScreenManager_RequestExitFullScreen = 1333
    , WebFullScreenManager_WillEnterFullScreen = 1334
    , WebFullScreenManager_DidEnterFullScreen = 1335
    , WebFullScreenManager_WillExitFullScreen = 1336
    , WebFullScreenManager_DidExitFullScreen = 1337
    , WebFullScreenManager_SetAnimatingFullScreen = 1338
    , WebFullScreenManager_SaveScrollPosition = 1339
    , WebFullScreenManager_RestoreScrollPosition = 1340
    , WebFullScreenManager_SetFullscreenInsets = 1341
    , WebFullScreenManager_SetFullscreenAutoHideDuration = 1342
    , WebFullScreenManager_SetFullscreenControlsHidden = 1343
    , GPUProcessConnection_DidReceiveRemoteCommand = 1344
    , RemoteRenderingBackend_CreateImageBufferBackend = 1345
    , RemoteRenderingBackend_CommitImageBufferFlushContext = 1346
    , MediaPlayerPrivateRemote_NetworkStateChanged = 1347
    , MediaPlayerPrivateRemote_ReadyStateChanged = 1348
    , MediaPlayerPrivateRemote_FirstVideoFrameAvailable = 1349
    , MediaPlayerPrivateRemote_VolumeChanged = 1350
    , MediaPlayerPrivateRemote_MuteChanged = 1351
    , MediaPlayerPrivateRemote_TimeChanged = 1352
    , MediaPlayerPrivateRemote_DurationChanged = 1353
    , MediaPlayerPrivateRemote_RateChanged = 1354
    , MediaPlayerPrivateRemote_PlaybackStateChanged = 1355
    , MediaPlayerPrivateRemote_EngineFailedToLoad = 1356
    , MediaPlayerPrivateRemote_UpdateCachedState = 1357
    , MediaPlayerPrivateRemote_CharacteristicChanged = 1358
    , MediaPlayerPrivateRemote_SizeChanged = 1359
    , MediaPlayerPrivateRemote_AddRemoteAudioTrack = 1360
    , MediaPlayerPrivateRemote_RemoveRemoteAudioTrack = 1361
    , MediaPlayerPrivateRemote_RemoteAudioTrackConfigurationChanged = 1362
    , MediaPlayerPrivateRemote_AddRemoteTextTrack = 1363
    , MediaPlayerPrivateRemote_RemoveRemoteTextTrack = 1364
    , MediaPlayerPrivateRemote_RemoteTextTrackConfigurationChanged = 1365
    , MediaPlayerPrivateRemote_ParseWebVTTFileHeader = 1366
    , MediaPlayerPrivateRemote_ParseWebVTTCueData = 1367
    , MediaPlayerPrivateRemote_ParseWebVTTCueDataStruct = 1368
    , MediaPlayerPrivateRemote_AddDataCue = 1369
#if ENABLE(DATACUE_VALUE)
    , MediaPlayerPrivateRemote_AddDataCueWithType = 1370
#endif
#if ENABLE(DATACUE_VALUE)
    , MediaPlayerPrivateRemote_UpdateDataCue = 1371
#endif
#if ENABLE(DATACUE_VALUE)
    , MediaPlayerPrivateRemote_RemoveDataCue = 1372
#endif
    , MediaPlayerPrivateRemote_AddGenericCue = 1373
    , MediaPlayerPrivateRemote_UpdateGenericCue = 1374
    , MediaPlayerPrivateRemote_RemoveGenericCue = 1375
    , MediaPlayerPrivateRemote_AddRemoteVideoTrack = 1376
    , MediaPlayerPrivateRemote_RemoveRemoteVideoTrack = 1377
    , MediaPlayerPrivateRemote_RemoteVideoTrackConfigurationChanged = 1378
    , MediaPlayerPrivateRemote_RequestResource = 1379
    , MediaPlayerPrivateRemote_RequestResourceReply = 1380
    , MediaPlayerPrivateRemote_RemoveResource = 1381
    , MediaPlayerPrivateRemote_ResourceNotSupported = 1382
    , MediaPlayerPrivateRemote_EngineUpdated = 1383
    , MediaPlayerPrivateRemote_ActiveSourceBuffersChanged = 1384
#if ENABLE(ENCRYPTED_MEDIA)
    , MediaPlayerPrivateRemote_WaitingForKeyChanged = 1385
#endif
#if ENABLE(ENCRYPTED_MEDIA)
    , MediaPlayerPrivateRemote_InitializationDataEncountered = 1386
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    , MediaPlayerPrivateRemote_MediaPlayerKeyNeeded = 1387
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET)
    , MediaPlayerPrivateRemote_CurrentPlaybackTargetIsWirelessChanged = 1388
#endif
    , RemoteAudioDestinationProxy_RenderBuffer = 1389
    , RemoteAudioDestinationProxy_RenderBufferReply = 1390
    , RemoteAudioDestinationProxy_DidChangeIsPlaying = 1391
    , RemoteAudioSession_ConfigurationChanged = 1392
    , RemoteAudioSession_BeginInterruption = 1393
    , RemoteAudioSession_EndInterruption = 1394
    , RemoteCDMInstanceSession_UpdateKeyStatuses = 1395
    , RemoteCDMInstanceSession_SendMessage = 1396
    , RemoteCDMInstanceSession_SessionIdChanged = 1397
    , RemoteLegacyCDMSession_SendMessage = 1398
    , RemoteLegacyCDMSession_SendError = 1399
    , LibWebRTCCodecs_FailedDecoding = 1400
    , LibWebRTCCodecs_CompletedDecoding = 1401
    , LibWebRTCCodecs_CompletedEncoding = 1402
    , SampleBufferDisplayLayer_SetDidFail = 1403
    , WebGeolocationManager_DidChangePosition = 1404
    , WebGeolocationManager_DidFailToDeterminePosition = 1405
#if PLATFORM(IOS_FAMILY)
    , WebGeolocationManager_ResetPermissions = 1406
#endif
    , RemoteWebInspectorUI_Initialize = 1407
    , RemoteWebInspectorUI_UpdateFindString = 1408
#if ENABLE(INSPECTOR_TELEMETRY)
    , RemoteWebInspectorUI_SetDiagnosticLoggingAvailable = 1409
#endif
    , RemoteWebInspectorUI_DidSave = 1410
    , RemoteWebInspectorUI_DidAppend = 1411
    , RemoteWebInspectorUI_SendMessageToFrontend = 1412
    , WebInspector_Show = 1413
    , WebInspector_Close = 1414
    , WebInspector_SetAttached = 1415
    , WebInspector_ShowConsole = 1416
    , WebInspector_ShowResources = 1417
    , WebInspector_ShowMainResourceForFrame = 1418
    , WebInspector_OpenInNewTab = 1419
    , WebInspector_StartPageProfiling = 1420
    , WebInspector_StopPageProfiling = 1421
    , WebInspector_StartElementSelection = 1422
    , WebInspector_StopElementSelection = 1423
    , WebInspector_SetFrontendConnection = 1424
    , WebInspectorInterruptDispatcher_NotifyNeedDebuggerBreak = 1425
    , WebInspectorUI_EstablishConnection = 1426
    , WebInspectorUI_UpdateConnection = 1427
    , WebInspectorUI_AttachedBottom = 1428
    , WebInspectorUI_AttachedRight = 1429
    , WebInspectorUI_AttachedLeft = 1430
    , WebInspectorUI_Detached = 1431
    , WebInspectorUI_SetDockingUnavailable = 1432
    , WebInspectorUI_SetIsVisible = 1433
    , WebInspectorUI_UpdateFindString = 1434
#if ENABLE(INSPECTOR_TELEMETRY)
    , WebInspectorUI_SetDiagnosticLoggingAvailable = 1435
#endif
    , WebInspectorUI_ShowConsole = 1436
    , WebInspectorUI_ShowResources = 1437
    , WebInspectorUI_ShowMainResourceForFrame = 1438
    , WebInspectorUI_StartPageProfiling = 1439
    , WebInspectorUI_StopPageProfiling = 1440
    , WebInspectorUI_StartElementSelection = 1441
    , WebInspectorUI_StopElementSelection = 1442
    , WebInspectorUI_DidSave = 1443
    , WebInspectorUI_DidAppend = 1444
    , WebInspectorUI_SendMessageToFrontend = 1445
    , LibWebRTCNetwork_SignalReadPacket = 1446
    , LibWebRTCNetwork_SignalSentPacket = 1447
    , LibWebRTCNetwork_SignalAddressReady = 1448
    , LibWebRTCNetwork_SignalConnect = 1449
    , LibWebRTCNetwork_SignalClose = 1450
    , LibWebRTCNetwork_SignalNewConnection = 1451
    , WebMDNSRegister_FinishedRegisteringMDNSName = 1452
    , WebRTCMonitor_NetworksChanged = 1453
    , WebRTCResolver_SetResolvedAddress = 1454
    , WebRTCResolver_ResolvedAddressError = 1455
#if ENABLE(SHAREABLE_RESOURCE)
    , NetworkProcessConnection_DidCacheResource = 1456
#endif
    , NetworkProcessConnection_DidFinishPingLoad = 1457
    , NetworkProcessConnection_DidFinishPreconnection = 1458
    , NetworkProcessConnection_SetOnLineState = 1459
    , NetworkProcessConnection_CookieAcceptPolicyChanged = 1460
#if HAVE(COOKIE_CHANGE_LISTENER_API)
    , NetworkProcessConnection_CookiesAdded = 1461
#endif
#if HAVE(COOKIE_CHANGE_LISTENER_API)
    , NetworkProcessConnection_CookiesDeleted = 1462
#endif
#if HAVE(COOKIE_CHANGE_LISTENER_API)
    , NetworkProcessConnection_AllCookiesDeleted = 1463
#endif
    , NetworkProcessConnection_CheckProcessLocalPortForActivity = 1464
    , NetworkProcessConnection_CheckProcessLocalPortForActivityReply = 1465
    , NetworkProcessConnection_MessagesAvailableForPort = 1466
    , NetworkProcessConnection_BroadcastConsoleMessage = 1467
    , WebResourceLoader_WillSendRequest = 1468
    , WebResourceLoader_DidSendData = 1469
    , WebResourceLoader_DidReceiveResponse = 1470
    , WebResourceLoader_DidReceiveData = 1471
    , WebResourceLoader_DidReceiveSharedBuffer = 1472
    , WebResourceLoader_DidFinishResourceLoad = 1473
    , WebResourceLoader_DidFailResourceLoad = 1474
    , WebResourceLoader_DidFailServiceWorkerLoad = 1475
    , WebResourceLoader_ServiceWorkerDidNotHandle = 1476
    , WebResourceLoader_DidBlockAuthenticationChallenge = 1477
    , WebResourceLoader_StopLoadingAfterXFrameOptionsOrContentSecurityPolicyDenied = 1478
#if ENABLE(SHAREABLE_RESOURCE)
    , WebResourceLoader_DidReceiveResource = 1479
#endif
    , WebSocketChannel_DidConnect = 1480
    , WebSocketChannel_DidClose = 1481
    , WebSocketChannel_DidReceiveText = 1482
    , WebSocketChannel_DidReceiveBinaryData = 1483
    , WebSocketChannel_DidReceiveMessageError = 1484
    , WebSocketChannel_DidSendHandshakeRequest = 1485
    , WebSocketChannel_DidReceiveHandshakeResponse = 1486
    , WebSocketStream_DidOpenSocketStream = 1487
    , WebSocketStream_DidCloseSocketStream = 1488
    , WebSocketStream_DidReceiveSocketStreamData = 1489
    , WebSocketStream_DidFailToReceiveSocketStreamData = 1490
    , WebSocketStream_DidUpdateBufferedAmount = 1491
    , WebSocketStream_DidFailSocketStream = 1492
    , WebSocketStream_DidSendData = 1493
    , WebSocketStream_DidSendHandshake = 1494
    , WebNotificationManager_DidShowNotification = 1495
    , WebNotificationManager_DidClickNotification = 1496
    , WebNotificationManager_DidCloseNotifications = 1497
    , WebNotificationManager_DidUpdateNotificationDecision = 1498
    , WebNotificationManager_DidRemoveNotificationDecisions = 1499
    , PluginProcessConnection_SetException = 1500
    , PluginProcessConnectionManager_PluginProcessCrashed = 1501
    , PluginProxy_LoadURL = 1502
    , PluginProxy_Update = 1503
    , PluginProxy_ProxiesForURL = 1504
    , PluginProxy_CookiesForURL = 1505
    , PluginProxy_SetCookiesForURL = 1506
    , PluginProxy_GetAuthenticationInfo = 1507
    , PluginProxy_GetPluginElementNPObject = 1508
    , PluginProxy_Evaluate = 1509
    , PluginProxy_CancelStreamLoad = 1510
    , PluginProxy_ContinueStreamLoad = 1511
    , PluginProxy_CancelManualStreamLoad = 1512
    , PluginProxy_SetStatusbarText = 1513
#if PLATFORM(COCOA)
    , PluginProxy_PluginFocusOrWindowFocusChanged = 1514
#endif
#if PLATFORM(COCOA)
    , PluginProxy_SetComplexTextInputState = 1515
#endif
#if PLATFORM(COCOA)
    , PluginProxy_SetLayerHostingContextID = 1516
#endif
#if PLATFORM(X11)
    , PluginProxy_CreatePluginContainer = 1517
#endif
#if PLATFORM(X11)
    , PluginProxy_WindowedPluginGeometryDidChange = 1518
#endif
#if PLATFORM(X11)
    , PluginProxy_WindowedPluginVisibilityDidChange = 1519
#endif
    , PluginProxy_DidCreatePlugin = 1520
    , PluginProxy_DidFailToCreatePlugin = 1521
    , PluginProxy_SetPluginIsPlayingAudio = 1522
    , WebSWClientConnection_JobRejectedInServer = 1523
    , WebSWClientConnection_RegistrationJobResolvedInServer = 1524
    , WebSWClientConnection_StartScriptFetchForServer = 1525
    , WebSWClientConnection_UpdateRegistrationState = 1526
    , WebSWClientConnection_UpdateWorkerState = 1527
    , WebSWClientConnection_FireUpdateFoundEvent = 1528
    , WebSWClientConnection_SetRegistrationLastUpdateTime = 1529
    , WebSWClientConnection_SetRegistrationUpdateViaCache = 1530
    , WebSWClientConnection_NotifyClientsOfControllerChange = 1531
    , WebSWClientConnection_SetSWOriginTableIsImported = 1532
    , WebSWClientConnection_SetSWOriginTableSharedMemory = 1533
    , WebSWClientConnection_PostMessageToServiceWorkerClient = 1534
    , WebSWClientConnection_DidMatchRegistration = 1535
    , WebSWClientConnection_DidGetRegistrations = 1536
    , WebSWClientConnection_RegistrationReady = 1537
    , WebSWClientConnection_SetDocumentIsControlled = 1538
    , WebSWClientConnection_SetDocumentIsControlledReply = 1539
    , WebSWContextManagerConnection_InstallServiceWorker = 1540
    , WebSWContextManagerConnection_StartFetch = 1541
    , WebSWContextManagerConnection_CancelFetch = 1542
    , WebSWContextManagerConnection_ContinueDidReceiveFetchResponse = 1543
    , WebSWContextManagerConnection_PostMessageToServiceWorker = 1544
    , WebSWContextManagerConnection_FireInstallEvent = 1545
    , WebSWContextManagerConnection_FireActivateEvent = 1546
    , WebSWContextManagerConnection_TerminateWorker = 1547
    , WebSWContextManagerConnection_FindClientByIdentifierCompleted = 1548
    , WebSWContextManagerConnection_MatchAllCompleted = 1549
    , WebSWContextManagerConnection_SetUserAgent = 1550
    , WebSWContextManagerConnection_UpdatePreferencesStore = 1551
    , WebSWContextManagerConnection_Close = 1552
    , WebSWContextManagerConnection_SetThrottleState = 1553
    , WebUserContentController_AddContentWorlds = 1554
    , WebUserContentController_RemoveContentWorlds = 1555
    , WebUserContentController_AddUserScripts = 1556
    , WebUserContentController_RemoveUserScript = 1557
    , WebUserContentController_RemoveAllUserScripts = 1558
    , WebUserContentController_AddUserStyleSheets = 1559
    , WebUserContentController_RemoveUserStyleSheet = 1560
    , WebUserContentController_RemoveAllUserStyleSheets = 1561
    , WebUserContentController_AddUserScriptMessageHandlers = 1562
    , WebUserContentController_RemoveUserScriptMessageHandler = 1563
    , WebUserContentController_RemoveAllUserScriptMessageHandlersForWorlds = 1564
    , WebUserContentController_RemoveAllUserScriptMessageHandlers = 1565
#if ENABLE(CONTENT_EXTENSIONS)
    , WebUserContentController_AddContentRuleLists = 1566
#endif
#if ENABLE(CONTENT_EXTENSIONS)
    , WebUserContentController_RemoveContentRuleList = 1567
#endif
#if ENABLE(CONTENT_EXTENSIONS)
    , WebUserContentController_RemoveAllContentRuleLists = 1568
#endif
#if USE(COORDINATED_GRAPHICS) || USE(TEXTURE_MAPPER)
    , DrawingArea_UpdateBackingStoreState = 1569
#endif
    , DrawingArea_DidUpdate = 1570
#if PLATFORM(COCOA)
    , DrawingArea_UpdateGeometry = 1571
#endif
#if PLATFORM(COCOA)
    , DrawingArea_SetDeviceScaleFactor = 1572
#endif
#if PLATFORM(COCOA)
    , DrawingArea_SetColorSpace = 1573
#endif
#if PLATFORM(COCOA)
    , DrawingArea_SetViewExposedRect = 1574
#endif
#if PLATFORM(COCOA)
    , DrawingArea_AdjustTransientZoom = 1575
#endif
#if PLATFORM(COCOA)
    , DrawingArea_CommitTransientZoom = 1576
#endif
#if PLATFORM(COCOA)
    , DrawingArea_AcceleratedAnimationDidStart = 1577
#endif
#if PLATFORM(COCOA)
    , DrawingArea_AcceleratedAnimationDidEnd = 1578
#endif
#if PLATFORM(COCOA)
    , DrawingArea_AddTransactionCallbackID = 1579
#endif
    , EventDispatcher_WheelEvent = 1580
#if ENABLE(IOS_TOUCH_EVENTS)
    , EventDispatcher_TouchEvent = 1581
#endif
#if ENABLE(MAC_GESTURE_EVENTS)
    , EventDispatcher_GestureEvent = 1582
#endif
#if ENABLE(WEBPROCESS_WINDOWSERVER_BLOCKING)
    , EventDispatcher_DisplayWasRefreshed = 1583
#endif
    , VisitedLinkTableController_SetVisitedLinkTable = 1584
    , VisitedLinkTableController_VisitedLinkStateChanged = 1585
    , VisitedLinkTableController_AllVisitedLinkStateChanged = 1586
    , VisitedLinkTableController_RemoveAllVisitedLinks = 1587
    , WebPage_SetInitialFocus = 1588
    , WebPage_SetInitialFocusReply = 1589
    , WebPage_SetActivityState = 1590
    , WebPage_SetLayerHostingMode = 1591
    , WebPage_SetBackgroundColor = 1592
    , WebPage_AddConsoleMessage = 1593
    , WebPage_SendCSPViolationReport = 1594
    , WebPage_EnqueueSecurityPolicyViolationEvent = 1595
    , WebPage_TestProcessIncomingSyncMessagesWhenWaitingForSyncReply = 1596
#if PLATFORM(COCOA)
    , WebPage_SetTopContentInsetFenced = 1597
#endif
    , WebPage_SetTopContentInset = 1598
    , WebPage_SetUnderlayColor = 1599
    , WebPage_ViewWillStartLiveResize = 1600
    , WebPage_ViewWillEndLiveResize = 1601
    , WebPage_ExecuteEditCommandWithCallback = 1602
    , WebPage_ExecuteEditCommandWithCallbackReply = 1603
    , WebPage_KeyEvent = 1604
    , WebPage_MouseEvent = 1605
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetViewportConfigurationViewLayoutSize = 1606
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetMaximumUnobscuredSize = 1607
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetDeviceOrientation = 1608
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetOverrideViewportArguments = 1609
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_DynamicViewportSizeUpdate = 1610
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetScreenIsBeingCaptured = 1611
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_HandleTap = 1612
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_PotentialTapAtPosition = 1613
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_CommitPotentialTap = 1614
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_CancelPotentialTap = 1615
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_TapHighlightAtPosition = 1616
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_DidRecognizeLongPress = 1617
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_HandleDoubleTapForDoubleClickAtPoint = 1618
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_InspectorNodeSearchMovedToPosition = 1619
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_InspectorNodeSearchEndedAtPosition = 1620
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_BlurFocusedElement = 1621
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SelectWithGesture = 1622
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_UpdateSelectionWithTouches = 1623
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SelectWithTwoTouches = 1624
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ExtendSelection = 1625
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SelectWordBackward = 1626
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_MoveSelectionByOffset = 1627
    , WebPage_MoveSelectionByOffsetReply = 1628
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SelectTextWithGranularityAtPoint = 1629
    , WebPage_SelectTextWithGranularityAtPointReply = 1630
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SelectPositionAtBoundaryWithDirection = 1631
    , WebPage_SelectPositionAtBoundaryWithDirectionReply = 1632
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_MoveSelectionAtBoundaryWithDirection = 1633
    , WebPage_MoveSelectionAtBoundaryWithDirectionReply = 1634
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SelectPositionAtPoint = 1635
    , WebPage_SelectPositionAtPointReply = 1636
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_BeginSelectionInDirection = 1637
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_UpdateSelectionWithExtentPoint = 1638
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_UpdateSelectionWithExtentPointAndBoundary = 1639
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RequestDictationContext = 1640
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ReplaceDictatedText = 1641
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ReplaceSelectedText = 1642
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RequestAutocorrectionData = 1643
    , WebPage_RequestAutocorrectionDataReply = 1644
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplyAutocorrection = 1645
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SyncApplyAutocorrection = 1646
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RequestAutocorrectionContext = 1647
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RequestEvasionRectsAboveSelection = 1648
    , WebPage_RequestEvasionRectsAboveSelectionReply = 1649
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_GetPositionInformation = 1650
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RequestPositionInformation = 1651
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_StartInteractionWithElementContextOrPosition = 1652
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_StopInteraction = 1653
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_PerformActionOnElement = 1654
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_FocusNextFocusedElement = 1655
    , WebPage_FocusNextFocusedElementReply = 1656
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetFocusedElementValue = 1657
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_AutofillLoginCredentials = 1658
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetFocusedElementValueAsNumber = 1659
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetFocusedElementSelectedIndex = 1660
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplicationWillResignActive = 1661
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplicationDidEnterBackground = 1662
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplicationDidFinishSnapshottingAfterEnteringBackground = 1663
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplicationWillEnterForeground = 1664
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplicationDidBecomeActive = 1665
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplicationDidEnterBackgroundForMedia = 1666
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ApplicationWillEnterForegroundForMedia = 1667
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ContentSizeCategoryDidChange = 1668
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_GetSelectionContext = 1669
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetAllowsMediaDocumentInlinePlayback = 1670
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_HandleTwoFingerTapAtPoint = 1671
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_HandleStylusSingleTapAtPoint = 1672
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetForceAlwaysUserScalable = 1673
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_GetRectsForGranularityWithSelectionOffset = 1674
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_GetRectsAtSelectionOffsetWithText = 1675
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_StoreSelectionForAccessibility = 1676
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_StartAutoscrollAtPosition = 1677
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_CancelAutoscroll = 1678
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RequestFocusedElementInformation = 1679
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_HardwareKeyboardAvailabilityChanged = 1680
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetIsShowingInputViewForFocusedElement = 1681
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_UpdateSelectionWithDelta = 1682
    , WebPage_UpdateSelectionWithDeltaReply = 1683
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RequestDocumentEditingContext = 1684
    , WebPage_RequestDocumentEditingContextReply = 1685
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_GenerateSyntheticEditingCommand = 1686
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_SetShouldRevealCurrentSelectionAfterInsertion = 1687
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_InsertTextPlaceholder = 1688
    , WebPage_InsertTextPlaceholderReply = 1689
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_RemoveTextPlaceholder = 1690
    , WebPage_RemoveTextPlaceholderReply = 1691
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_TextInputContextsInRect = 1692
    , WebPage_TextInputContextsInRectReply = 1693
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_FocusTextInputContextAndPlaceCaret = 1694
    , WebPage_FocusTextInputContextAndPlaceCaretReply = 1695
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_ClearServiceWorkerEntitlementOverride = 1696
    , WebPage_ClearServiceWorkerEntitlementOverrideReply = 1697
#endif
    , WebPage_SetControlledByAutomation = 1698
    , WebPage_ConnectInspector = 1699
    , WebPage_DisconnectInspector = 1700
    , WebPage_SendMessageToTargetBackend = 1701
#if ENABLE(REMOTE_INSPECTOR)
    , WebPage_SetIndicating = 1702
#endif
#if ENABLE(IOS_TOUCH_EVENTS)
    , WebPage_ResetPotentialTapSecurityOrigin = 1703
#endif
#if ENABLE(IOS_TOUCH_EVENTS)
    , WebPage_TouchEventSync = 1704
#endif
#if !ENABLE(IOS_TOUCH_EVENTS) && ENABLE(TOUCH_EVENTS)
    , WebPage_TouchEvent = 1705
#endif
    , WebPage_CancelPointer = 1706
    , WebPage_TouchWithIdentifierWasRemoved = 1707
#if ENABLE(INPUT_TYPE_COLOR)
    , WebPage_DidEndColorPicker = 1708
#endif
#if ENABLE(INPUT_TYPE_COLOR)
    , WebPage_DidChooseColor = 1709
#endif
#if ENABLE(DATALIST_ELEMENT)
    , WebPage_DidSelectDataListOption = 1710
#endif
#if ENABLE(DATALIST_ELEMENT)
    , WebPage_DidCloseSuggestions = 1711
#endif
#if ENABLE(CONTEXT_MENUS)
    , WebPage_ContextMenuHidden = 1712
#endif
#if ENABLE(CONTEXT_MENUS)
    , WebPage_ContextMenuForKeyEvent = 1713
#endif
    , WebPage_ScrollBy = 1714
    , WebPage_CenterSelectionInVisibleArea = 1715
    , WebPage_GoToBackForwardItem = 1716
    , WebPage_TryRestoreScrollPosition = 1717
    , WebPage_LoadURLInFrame = 1718
    , WebPage_LoadDataInFrame = 1719
    , WebPage_LoadRequest = 1720
    , WebPage_LoadRequestWaitingForProcessLaunch = 1721
    , WebPage_LoadData = 1722
    , WebPage_LoadAlternateHTML = 1723
    , WebPage_NavigateToPDFLinkWithSimulatedClick = 1724
    , WebPage_Reload = 1725
    , WebPage_StopLoading = 1726
    , WebPage_StopLoadingFrame = 1727
    , WebPage_RestoreSession = 1728
    , WebPage_UpdateBackForwardListForReattach = 1729
    , WebPage_SetCurrentHistoryItemForReattach = 1730
    , WebPage_DidRemoveBackForwardItem = 1731
    , WebPage_UpdateWebsitePolicies = 1732
    , WebPage_NotifyUserScripts = 1733
    , WebPage_DidReceivePolicyDecision = 1734
    , WebPage_ContinueWillSubmitForm = 1735
    , WebPage_ClearSelection = 1736
    , WebPage_RestoreSelectionInFocusedEditableElement = 1737
    , WebPage_GetContentsAsString = 1738
    , WebPage_GetAllFrames = 1739
    , WebPage_GetAllFramesReply = 1740
#if PLATFORM(COCOA)
    , WebPage_GetContentsAsAttributedString = 1741
    , WebPage_GetContentsAsAttributedStringReply = 1742
#endif
#if ENABLE(MHTML)
    , WebPage_GetContentsAsMHTMLData = 1743
#endif
    , WebPage_GetMainResourceDataOfFrame = 1744
    , WebPage_GetResourceDataFromFrame = 1745
    , WebPage_GetRenderTreeExternalRepresentation = 1746
    , WebPage_GetSelectionOrContentsAsString = 1747
    , WebPage_GetSelectionAsWebArchiveData = 1748
    , WebPage_GetSourceForFrame = 1749
    , WebPage_GetWebArchiveOfFrame = 1750
    , WebPage_RunJavaScriptInFrameInScriptWorld = 1751
    , WebPage_ForceRepaint = 1752
    , WebPage_SelectAll = 1753
    , WebPage_ScheduleFullEditorStateUpdate = 1754
#if PLATFORM(COCOA)
    , WebPage_PerformDictionaryLookupOfCurrentSelection = 1755
#endif
#if PLATFORM(COCOA)
    , WebPage_PerformDictionaryLookupAtLocation = 1756
#endif
#if ENABLE(DATA_DETECTION)
    , WebPage_DetectDataInAllFrames = 1757
    , WebPage_DetectDataInAllFramesReply = 1758
#endif
#if ENABLE(DATA_DETECTION)
    , WebPage_RemoveDataDetectedLinks = 1759
    , WebPage_RemoveDataDetectedLinksReply = 1760
#endif
    , WebPage_ChangeFont = 1761
    , WebPage_ChangeFontAttributes = 1762
    , WebPage_PreferencesDidChange = 1763
    , WebPage_SetUserAgent = 1764
    , WebPage_SetCustomTextEncodingName = 1765
    , WebPage_SuspendActiveDOMObjectsAndAnimations = 1766
    , WebPage_ResumeActiveDOMObjectsAndAnimations = 1767
    , WebPage_Close = 1768
    , WebPage_TryClose = 1769
    , WebPage_TryCloseReply = 1770
    , WebPage_SetEditable = 1771
    , WebPage_ValidateCommand = 1772
    , WebPage_ExecuteEditCommand = 1773
    , WebPage_IncreaseListLevel = 1774
    , WebPage_DecreaseListLevel = 1775
    , WebPage_ChangeListType = 1776
    , WebPage_SetBaseWritingDirection = 1777
    , WebPage_SetNeedsFontAttributes = 1778
    , WebPage_RequestFontAttributesAtSelectionStart = 1779
    , WebPage_DidRemoveEditCommand = 1780
    , WebPage_ReapplyEditCommand = 1781
    , WebPage_UnapplyEditCommand = 1782
    , WebPage_SetPageAndTextZoomFactors = 1783
    , WebPage_SetPageZoomFactor = 1784
    , WebPage_SetTextZoomFactor = 1785
    , WebPage_WindowScreenDidChange = 1786
    , WebPage_AccessibilitySettingsDidChange = 1787
    , WebPage_ScalePage = 1788
    , WebPage_ScalePageInViewCoordinates = 1789
    , WebPage_ScaleView = 1790
    , WebPage_SetUseFixedLayout = 1791
    , WebPage_SetFixedLayoutSize = 1792
    , WebPage_ListenForLayoutMilestones = 1793
    , WebPage_SetSuppressScrollbarAnimations = 1794
    , WebPage_SetEnableVerticalRubberBanding = 1795
    , WebPage_SetEnableHorizontalRubberBanding = 1796
    , WebPage_SetBackgroundExtendsBeyondPage = 1797
    , WebPage_SetPaginationMode = 1798
    , WebPage_SetPaginationBehavesLikeColumns = 1799
    , WebPage_SetPageLength = 1800
    , WebPage_SetGapBetweenPages = 1801
    , WebPage_SetPaginationLineGridEnabled = 1802
    , WebPage_PostInjectedBundleMessage = 1803
    , WebPage_FindString = 1804
    , WebPage_FindStringMatches = 1805
    , WebPage_GetImageForFindMatch = 1806
    , WebPage_SelectFindMatch = 1807
    , WebPage_IndicateFindMatch = 1808
    , WebPage_HideFindUI = 1809
    , WebPage_CountStringMatches = 1810
    , WebPage_ReplaceMatches = 1811
    , WebPage_AddMIMETypeWithCustomContentProvider = 1812
#if PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
    , WebPage_PerformDragControllerAction = 1813
#endif
#if !PLATFORM(GTK) && ENABLE(DRAG_SUPPORT)
    , WebPage_PerformDragControllerAction = 1814
#endif
#if ENABLE(DRAG_SUPPORT)
    , WebPage_DidStartDrag = 1815
#endif
#if ENABLE(DRAG_SUPPORT)
    , WebPage_DragEnded = 1816
#endif
#if ENABLE(DRAG_SUPPORT)
    , WebPage_DragCancelled = 1817
#endif
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
    , WebPage_RequestDragStart = 1818
#endif
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
    , WebPage_RequestAdditionalItemsForDragSession = 1819
#endif
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
    , WebPage_InsertDroppedImagePlaceholders = 1820
    , WebPage_InsertDroppedImagePlaceholdersReply = 1821
#endif
#if PLATFORM(IOS_FAMILY) && ENABLE(DRAG_SUPPORT)
    , WebPage_DidConcludeDrop = 1822
#endif
    , WebPage_DidChangeSelectedIndexForActivePopupMenu = 1823
    , WebPage_SetTextForActivePopupMenu = 1824
#if PLATFORM(GTK)
    , WebPage_FailedToShowPopupMenu = 1825
#endif
#if ENABLE(CONTEXT_MENUS)
    , WebPage_DidSelectItemFromActiveContextMenu = 1826
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_DidChooseFilesForOpenPanelWithDisplayStringAndIcon = 1827
#endif
    , WebPage_DidChooseFilesForOpenPanel = 1828
    , WebPage_DidCancelForOpenPanel = 1829
#if ENABLE(SANDBOX_EXTENSIONS)
    , WebPage_ExtendSandboxForFilesFromOpenPanel = 1830
#endif
    , WebPage_AdvanceToNextMisspelling = 1831
    , WebPage_ChangeSpellingToWord = 1832
    , WebPage_DidFinishCheckingText = 1833
    , WebPage_DidCancelCheckingText = 1834
#if USE(APPKIT)
    , WebPage_UppercaseWord = 1835
#endif
#if USE(APPKIT)
    , WebPage_LowercaseWord = 1836
#endif
#if USE(APPKIT)
    , WebPage_CapitalizeWord = 1837
#endif
#if PLATFORM(COCOA)
    , WebPage_SetSmartInsertDeleteEnabled = 1838
#endif
#if ENABLE(GEOLOCATION)
    , WebPage_DidReceiveGeolocationPermissionDecision = 1839
#endif
#if ENABLE(MEDIA_STREAM)
    , WebPage_UserMediaAccessWasGranted = 1840
    , WebPage_UserMediaAccessWasGrantedReply = 1841
#endif
#if ENABLE(MEDIA_STREAM)
    , WebPage_UserMediaAccessWasDenied = 1842
#endif
#if ENABLE(MEDIA_STREAM)
    , WebPage_CaptureDevicesChanged = 1843
#endif
    , WebPage_StopAllMediaPlayback = 1844
    , WebPage_SuspendAllMediaPlayback = 1845
    , WebPage_ResumeAllMediaPlayback = 1846
    , WebPage_DidReceiveNotificationPermissionDecision = 1847
    , WebPage_FreezeLayerTreeDueToSwipeAnimation = 1848
    , WebPage_UnfreezeLayerTreeDueToSwipeAnimation = 1849
    , WebPage_BeginPrinting = 1850
    , WebPage_EndPrinting = 1851
    , WebPage_ComputePagesForPrinting = 1852
#if PLATFORM(COCOA)
    , WebPage_DrawRectToImage = 1853
#endif
#if PLATFORM(COCOA)
    , WebPage_DrawPagesToPDF = 1854
#endif
#if (PLATFORM(COCOA) && PLATFORM(IOS_FAMILY))
    , WebPage_ComputePagesForPrintingAndDrawToPDF = 1855
#endif
#if PLATFORM(COCOA)
    , WebPage_DrawToPDF = 1856
#endif
#if PLATFORM(GTK)
    , WebPage_DrawPagesForPrinting = 1857
#endif
    , WebPage_SetMediaVolume = 1858
    , WebPage_SetMuted = 1859
    , WebPage_SetMayStartMediaWhenInWindow = 1860
    , WebPage_StopMediaCapture = 1861
#if ENABLE(MEDIA_SESSION)
    , WebPage_HandleMediaEvent = 1862
#endif
#if ENABLE(MEDIA_SESSION)
    , WebPage_SetVolumeOfMediaElement = 1863
#endif
    , WebPage_SetCanRunBeforeUnloadConfirmPanel = 1864
    , WebPage_SetCanRunModal = 1865
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebPage_CancelComposition = 1866
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebPage_DeleteSurrounding = 1867
#endif
#if PLATFORM(GTK)
    , WebPage_CollapseSelectionInFrame = 1868
#endif
#if PLATFORM(GTK)
    , WebPage_GetCenterForZoomGesture = 1869
#endif
#if PLATFORM(COCOA)
    , WebPage_SendComplexTextInputToPlugin = 1870
#endif
#if PLATFORM(COCOA)
    , WebPage_WindowAndViewFramesChanged = 1871
#endif
#if PLATFORM(COCOA)
    , WebPage_SetMainFrameIsScrollable = 1872
#endif
#if PLATFORM(COCOA)
    , WebPage_RegisterUIProcessAccessibilityTokens = 1873
#endif
#if PLATFORM(COCOA)
    , WebPage_GetStringSelectionForPasteboard = 1874
#endif
#if PLATFORM(COCOA)
    , WebPage_GetDataSelectionForPasteboard = 1875
#endif
#if PLATFORM(COCOA)
    , WebPage_ReadSelectionFromPasteboard = 1876
#endif
#if (PLATFORM(COCOA) && ENABLE(SERVICE_CONTROLS))
    , WebPage_ReplaceSelectionWithPasteboardData = 1877
#endif
#if PLATFORM(COCOA)
    , WebPage_ShouldDelayWindowOrderingEvent = 1878
#endif
#if PLATFORM(COCOA)
    , WebPage_AcceptsFirstMouse = 1879
#endif
#if PLATFORM(COCOA)
    , WebPage_SetTextAsync = 1880
#endif
#if PLATFORM(COCOA)
    , WebPage_InsertTextAsync = 1881
#endif
#if PLATFORM(COCOA)
    , WebPage_InsertDictatedTextAsync = 1882
#endif
#if PLATFORM(COCOA)
    , WebPage_HasMarkedText = 1883
    , WebPage_HasMarkedTextReply = 1884
#endif
#if PLATFORM(COCOA)
    , WebPage_GetMarkedRangeAsync = 1885
#endif
#if PLATFORM(COCOA)
    , WebPage_GetSelectedRangeAsync = 1886
#endif
#if PLATFORM(COCOA)
    , WebPage_CharacterIndexForPointAsync = 1887
#endif
#if PLATFORM(COCOA)
    , WebPage_FirstRectForCharacterRangeAsync = 1888
#endif
#if PLATFORM(COCOA)
    , WebPage_SetCompositionAsync = 1889
#endif
#if PLATFORM(COCOA)
    , WebPage_ConfirmCompositionAsync = 1890
#endif
#if PLATFORM(MAC)
    , WebPage_AttributedSubstringForCharacterRangeAsync = 1891
#endif
#if PLATFORM(MAC)
    , WebPage_FontAtSelection = 1892
#endif
    , WebPage_SetAlwaysShowsHorizontalScroller = 1893
    , WebPage_SetAlwaysShowsVerticalScroller = 1894
    , WebPage_SetMinimumSizeForAutoLayout = 1895
    , WebPage_SetSizeToContentAutoSizeMaximumSize = 1896
    , WebPage_SetAutoSizingShouldExpandToViewHeight = 1897
    , WebPage_SetViewportSizeForCSSViewportUnits = 1898
#if PLATFORM(COCOA)
    , WebPage_HandleAlternativeTextUIResult = 1899
#endif
#if PLATFORM(IOS_FAMILY)
    , WebPage_WillStartUserTriggeredZooming = 1900
#endif
    , WebPage_SetScrollPinningBehavior = 1901
    , WebPage_SetScrollbarOverlayStyle = 1902
    , WebPage_GetBytecodeProfile = 1903
    , WebPage_GetSamplingProfilerOutput = 1904
    , WebPage_TakeSnapshot = 1905
#if PLATFORM(MAC)
    , WebPage_PerformImmediateActionHitTestAtLocation = 1906
#endif
#if PLATFORM(MAC)
    , WebPage_ImmediateActionDidUpdate = 1907
#endif
#if PLATFORM(MAC)
    , WebPage_ImmediateActionDidCancel = 1908
#endif
#if PLATFORM(MAC)
    , WebPage_ImmediateActionDidComplete = 1909
#endif
#if PLATFORM(MAC)
    , WebPage_DataDetectorsDidPresentUI = 1910
#endif
#if PLATFORM(MAC)
    , WebPage_DataDetectorsDidChangeUI = 1911
#endif
#if PLATFORM(MAC)
    , WebPage_DataDetectorsDidHideUI = 1912
#endif
#if PLATFORM(MAC)
    , WebPage_HandleAcceptedCandidate = 1913
#endif
#if PLATFORM(MAC)
    , WebPage_SetUseSystemAppearance = 1914
#endif
#if PLATFORM(MAC)
    , WebPage_SetHeaderBannerHeightForTesting = 1915
#endif
#if PLATFORM(MAC)
    , WebPage_SetFooterBannerHeightForTesting = 1916
#endif
#if PLATFORM(MAC)
    , WebPage_DidEndMagnificationGesture = 1917
#endif
    , WebPage_EffectiveAppearanceDidChange = 1918
#if PLATFORM(GTK)
    , WebPage_ThemeDidChange = 1919
#endif
#if PLATFORM(COCOA)
    , WebPage_RequestActiveNowPlayingSessionInfo = 1920
#endif
    , WebPage_SetShouldDispatchFakeMouseMoveEvents = 1921
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPage_PlaybackTargetSelected = 1922
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPage_PlaybackTargetAvailabilityDidChange = 1923
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPage_SetShouldPlayToPlaybackTarget = 1924
#endif
#if ENABLE(WIRELESS_PLAYBACK_TARGET) && !PLATFORM(IOS_FAMILY)
    , WebPage_PlaybackTargetPickerWasDismissed = 1925
#endif
#if ENABLE(POINTER_LOCK)
    , WebPage_DidAcquirePointerLock = 1926
#endif
#if ENABLE(POINTER_LOCK)
    , WebPage_DidNotAcquirePointerLock = 1927
#endif
#if ENABLE(POINTER_LOCK)
    , WebPage_DidLosePointerLock = 1928
#endif
    , WebPage_clearWheelEventTestMonitor = 1929
    , WebPage_SetShouldScaleViewToFitDocument = 1930
#if ENABLE(VIDEO) && USE(GSTREAMER)
    , WebPage_DidEndRequestInstallMissingMediaPlugins = 1931
#endif
    , WebPage_SetUserInterfaceLayoutDirection = 1932
    , WebPage_DidGetLoadDecisionForIcon = 1933
    , WebPage_SetUseIconLoadingClient = 1934
#if ENABLE(GAMEPAD)
    , WebPage_GamepadActivity = 1935
#endif
    , WebPage_FrameBecameRemote = 1936
    , WebPage_RegisterURLSchemeHandler = 1937
    , WebPage_URLSchemeTaskDidPerformRedirection = 1938
    , WebPage_URLSchemeTaskDidReceiveResponse = 1939
    , WebPage_URLSchemeTaskDidReceiveData = 1940
    , WebPage_URLSchemeTaskDidComplete = 1941
    , WebPage_SetIsSuspended = 1942
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPage_InsertAttachment = 1943
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPage_UpdateAttachmentAttributes = 1944
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    , WebPage_UpdateAttachmentIcon = 1945
#endif
#if ENABLE(APPLICATION_MANIFEST)
    , WebPage_GetApplicationManifest = 1946
#endif
    , WebPage_SetDefersLoading = 1947
    , WebPage_UpdateCurrentModifierState = 1948
    , WebPage_SimulateDeviceOrientationChange = 1949
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPage_SpeakingErrorOccurred = 1950
#endif
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPage_BoundaryEventOccurred = 1951
#endif
#if ENABLE(SPEECH_SYNTHESIS)
    , WebPage_VoicesDidChange = 1952
#endif
    , WebPage_SetCanShowPlaceholder = 1953
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , WebPage_WasLoadedWithDataTransferFromPrevalentResource = 1954
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , WebPage_ClearLoadedThirdPartyDomains = 1955
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    , WebPage_LoadedThirdPartyDomains = 1956
    , WebPage_LoadedThirdPartyDomainsReply = 1957
#endif
#if USE(SYSTEM_PREVIEW)
    , WebPage_SystemPreviewActionTriggered = 1958
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebPage_SendMessageToWebExtension = 1959
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    , WebPage_SendMessageToWebExtensionWithReply = 1960
    , WebPage_SendMessageToWebExtensionWithReplyReply = 1961
#endif
    , WebPage_StartTextManipulations = 1962
    , WebPage_StartTextManipulationsReply = 1963
    , WebPage_CompleteTextManipulation = 1964
    , WebPage_CompleteTextManipulationReply = 1965
    , WebPage_SetOverriddenMediaType = 1966
    , WebPage_GetProcessDisplayName = 1967
    , WebPage_GetProcessDisplayNameReply = 1968
    , WebPage_UpdateCORSDisablingPatterns = 1969
    , WebPage_SetShouldFireEvents = 1970
    , WebPage_SetNeedsDOMWindowResizeEvent = 1971
    , WebPage_SetHasResourceLoadClient = 1972
    , StorageAreaMap_DidSetItem = 1973
    , StorageAreaMap_DidRemoveItem = 1974
    , StorageAreaMap_DidClear = 1975
    , StorageAreaMap_DispatchStorageEvent = 1976
    , StorageAreaMap_ClearCache = 1977
#if PLATFORM(MAC)
    , ViewGestureController_DidCollectGeometryForMagnificationGesture = 1978
#endif
#if PLATFORM(MAC)
    , ViewGestureController_DidCollectGeometryForSmartMagnificationGesture = 1979
#endif
#if !PLATFORM(IOS_FAMILY)
    , ViewGestureController_DidHitRenderTreeSizeThreshold = 1980
#endif
#if PLATFORM(COCOA)
    , ViewGestureGeometryCollector_CollectGeometryForSmartMagnificationGesture = 1981
#endif
#if PLATFORM(MAC)
    , ViewGestureGeometryCollector_CollectGeometryForMagnificationGesture = 1982
#endif
#if !PLATFORM(IOS_FAMILY)
    , ViewGestureGeometryCollector_SetRenderTreeSizeNotificationThreshold = 1983
#endif
    , WrappedAsyncMessageForTesting = 1984
    , SyncMessageReply = 1985
    , InitializeConnection = 1986
    , LegacySessionState = 1987
};

ReceiverName receiverName(MessageName);
const char* description(MessageName);
bool isValidMessageName(MessageName);

} // namespace IPC

namespace WTF {

template<>
class HasCustomIsValidEnum<IPC::MessageName> : public std::true_type { };
template<typename E, typename T, std::enable_if_t<std::is_same_v<E, IPC::MessageName>>* = nullptr>
bool isValidEnum(T messageName)
{
    static_assert(sizeof(T) == sizeof(E), "isValidEnum<IPC::MessageName> should only be called with 16-bit types");
    return IPC::isValidMessageName(static_cast<E>(messageName));
};

} // namespace WTF
